<?php

namespace MGModule\AdvancedBilling\submodules;

use Exception;
use MGModule\AdvancedBilling as main;
use MGModule\AdvancedBilling\core\UsageRecord;
use MGModule\AdvancedBilling\submodules\easyDCIM\EasyDCIMConnection;

class EasyDCIMColocationRecords extends EasyDCIMRecords
{

    protected $name        = 'EasyDCIMColocation';
    protected $version     = "1.0";
    protected $description = '<a href="http://www.modulesgarden.com/products/whmcs/cpanel_extended/features">Easy DCIM Colocation Module</a> allows you to provide management of the hosting accounts in the client area.<br /><br />
        <strong>Advanced Billing</strong> module can set billing for usage of the accounts using Easy DCIM Colocation module.';
    protected $resources   = array(
        'bandwidth'  => array
            (
            'name'           => 'bandwidth',
            'friendlyName'   => 'Bandwidth',
            'description'    => 'Billing for Usage of Bandwidth',
            'unit'           => 'MB',
            'availableTypes' => array(parent::CALC_TYPE_LAST => "Last"),
            'availableUnits' => array
                (
                'MB' => 1,
                'GB' => 0.0009765625
            ),
        ),
        'percentile' => array
            (
            'name'           => 'percentile',
            'friendlyName'   => '95th Percentile',
            'description'    => 'Billing for 95th Percentile',
            'unit'           => 'Kbps',
            'availableTypes' => array(parent::CALC_TYPE_LAST => "Last"),
            'availableUnits' => array
                (
                'Kbps' => 1,
                'Mbps' => 0.000001
            ),
        ),
        'powerUsage' => array
            (
            'name'           => 'powerUsage',
            'friendlyName'   => 'Power Usage',
            'description'    => 'Billing for Power Usage',
            'unit'           => 'Amps',
            'availableTypes' => array(parent::CALC_TYPE_LAST => "Last"),
            'availableUnits' => array
                (
                'Amps' => 1,
            ),
        ),
    );

    public static function factory($pid)
    {
        return parent::buildFactory('EasyDCIMColocationRecords', $pid);
    }

    public function getSample()
    {


        //GET EasyDCIM API
        require_once __DIR__ . DS . 'easyDCIM' . DS . 'EasyDCIMConnection.php';
        $accounts = $this->getAvailableHostings();

        foreach ($accounts as $acc)
        {
            $customFields = $this->getAccountCustomFields($acc->id);
            $serverConfig = $this->getServerConfig($acc->server);

            //Skip when Server ID is empty;
            if (empty($customFields->serverID))
            {
                $this->forceLastTimeUpdate($acc->id);
                continue;
            }

            if (strtolower($acc->domainstatus) != 'active')
            {
                $this->forceLastTimeUpdate($acc->id);
                continue;
            }


            //Preapare EasyDCIM Hostname 
            $prefix = ($serverConfig->secure == 'on' || $serverConfig->secure == '1') ? 'https://' : 'http://';
            $apiURL = $prefix . ($serverConfig->hostname) ?: $serverConfig->ipaddress;
            //Get EasyDCIM API Key
            $apiKey = decrypt($serverConfig->password);

            try
            {

                $date = $this->getPerioid($acc);

                $newUsageTable = $this->getUsageRecords($apiURL, $apiKey, $customFields->serverID, $acc->id, $date);
                $this->insertRecord($acc->id, $newUsageTable["accountUsageRecords"]);


                $this->setLastTimeUpdate($acc->id);
            }
            catch (Exception $ex)
            {
                main\classes\Logger::error((new ReflectionClass($this))->getShortName() . ' Error: ' . $ex->getMessage());
            }
        }
    }

    public function getUsageRecords($apiURL, $apiKey, $serverID, $hostingID, $date)
    {
        $bandwith   = $this->getBandwidth($apiURL, $apiKey, $serverID, $date);
        $powerUsage = $this->getPowerUsage($apiURL, $apiKey, $serverID, $date);

        $usage["accountUsageRecords"] = $this->prepareUsageRecords($bandwith, $powerUsage);
        return $usage;
    }

    public function getBandwidth($apiURL, $apiKey, $serverID, $date)
    {
        $unit = [
            'units' => 'MB',
        ];

        $params = array_merge($date, $unit);

        $api = new EasyDCIMConnection($apiURL, $apiKey);
        return $api->post($params)->execut('device/' . $serverID . '/bandwidth');
    }

    public function getPowerUsage($apiURL, $apiKey, $serverID, $date)
    {
        $unit = [
            'units' => 'MB',
        ];

        $params = array_merge($date, $unit);

        $api = new EasyDCIMConnection($apiURL, $apiKey);
        return $api->post($params)->execut('device/' . $serverID . '/power-usage');
    }

    public function getNewSettings($time)
    {
        return array
            (
            'update'    => $time,
            'bandwidth' => ""
        );
    }

    public function prepareUsageRecords($bandwith, $powerusage)
    {

        $UsageRecords   = [];
        $UsageRecords[] = new UsageRecord('bandwidth', ($bandwith->{'BW_TOTAL'}) ?: 0);
        $UsageRecords[] = new UsageRecord('percentile', ($bandwith->{'95TH_PERC'}) ?: 0);
        $UsageRecords[] = new UsageRecord('powerUsage', ($powerusage->{'AVG_TOTAL_USAGE'}) ?: 0);


        return $UsageRecords;
    }

    public function getPerioid($hosting)
    {
        $startDate = $this->getStartDate($hosting);

        $endDate   = date('Y-m-d H:i:s');
        return [
            'startDate' => $startDate,
            'endDate'   => $endDate,
        ];
    }

    public function getStartDate($hosting)
    {
        $account = new main\classes\Account($hosting->id);


        $accountInfo = $account->getHourlyItems(1)->count();
        if ($accountInfo == 0)
        {
            $accountInfo = $account->getFreshItems(1)->count();
        }

        $data = $this->getHostingData($hosting->id);
        if ($accountInfo > 0 && $data['start_date'])
        {
            return $data['start_date'];
        }

        $date = date('Y-m-d H:i:s');
        $this->saveHostingData($hosting->id, [
            'start_date' => $date
        ]);


        return $date;
    }

}
