<?php

namespace MGModule\EasyDCIM\Controllers\Server\Admin;

use Exception;
use MGModule\EasyDCIM\MgLibs\Process\AbstractController;
use MGModule\EasyDCIM\Repositories\Configuration\ConfigurableOptions;
use MGModule\EasyDCIM\Repositories\Configuration\Configuration as ConfigurationRepostiory;

/**
 * Description of Configuration
 *
 * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
 */
class Configuration extends AbstractController
{

    /**
     * Get Configuration Form
     * 
     * @var array $input, $vars
     * @return array
     */
    public function indexHTML($input, $vars = [])
    {
        $repositories = new ConfigurationRepostiory($input);
        $vars         = $repositories->getForm();
        return array(
            'tpl'  => 'configuration',
            'vars' => $vars
        );
    }

    /**
     * Get Configurable options table
     * 
     * @var array $input
     * @return array
     */
    public function getConfigurableOptionsJSON($input)
    {
        try
        {
            $repositories = new ConfigurableOptions($input);
            return $repositories->get();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /**
     * Create Configurable options
     * 
     * @var array $input
     * @return array
     */
    public function createConfigurableOptionsJSON($input)
    {
        try
        {
            $repositories = new ConfigurableOptions($input);
            return $repositories->create();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /**
     * Get OS templates assigned to selected location
     * 
     * @var array $input
     * @return array
     */
    public function getOSTemplatesJSON($input)
    {
        try
        {
            $repositories = new ConfigurationRepostiory($input);
            return ['options' => $repositories->getOsTemplateList()];
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

}
