<?php

namespace MGModule\EasyDCIM\Controllers\Server\Admin;

use Exception;
use MGModule\EasyDCIM\MgLibs\Process\AbstractController;
use MGModule\EasyDCIM\Repositories\Device\Device;
use MGModule\EasyDCIM\Repositories\Graphs\Graph;
use MGModule\EasyDCIM\Repositories\Modules\UsageCollector;
use MGModule\EasyDCIM\Repositories\Product\ProductFields;
use MGModule\EasyDCIM\Server;

/**
 * Description of autologin
 *
 * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
 */
class Product extends AbstractController
{

    /**
     * Get Custom Information on Products/Services page
     *
     * @param array $params
     */
    public function indexHTML($params)
    {
        $repository = new ProductFields($params);
        return $repository->getCustomPage();
    }

    /**
     * Get JSON graphs
     *
     * @param array $params
     * 
     * @return array
     */
    public function getGraphJSON($params)
    {
        try
        {
            $repository = new Graph($params);
            $graph      = $repository->getAAGraphs();

            $usageRepository = new UsageCollector($params);
            $usage           = $usageRepository->getBandwidth(Server::getModuleTemplatesDir() . '/pages/deviceInformation/');

            return array_merge($graph, $usage);
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /**
     * Power ON Service JSON
     *
     * @param array $params
     * 
     * @return array
     */
    public function powerOnJSON($params)
    {
        try
        {
            $repository = new Device($params);
            return $repository->powerOn();
        }
        catch (Exception $ex)
        {
            return ['

            error

            ' => $ex->getMessage()];
        }
    }

    /**
     * Power Off Service JSON
     *
     * @param array $params
     * 
     * @return array
     */
    public function powerOffJSON($params)
    {
        try
        {
            $repository = new Device($params);
            return $repository->powerOff();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /**
     * Reboot Service JSON
     *
     * @param array $params
     * 
     * @return array
     */
    public function rebootJSON($params)
    {
        try
        {
            $repository = new Device($params);
            return $repository->reboot();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /**
     * Reboot Service JSON
     *
     * @param array $params
     *
     * @return array
     */
    public function coldResetJSON($params)
    {
        try
        {
            $repository = new Device($params);
            return $repository->coldReset();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /**
     * Get visible page on client area
     *
     * @param array $params
     * 
     * @return array
     */
    public function getPagesHTML($params)
    {
        $repository = new ProductFields($params);
        return $repository->getVisiblePages();
    }

}
