<?php

namespace MGModule\EasyDCIM\Controllers\Server\Clientarea;

use Exception;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Exceptions\FatalError;
use MGModule\EasyDCIM\MgLibs\Process\AbstractController;
use MGModule\EasyDCIM\Repositories\Modules\DnsManager as DnsManagerRepostiory;

/**
 * Description of home
 *
 * @author Michal Czech <michael@modulesgarden.com>
 */
class DnsManager extends AbstractController
{

    /**
     * Get Client Area main page
     *
     * @param array $params, $vars
     * 
     * @return array
     */
    function indexHTML($params, $vars = [])
    {
        try
        {
            $repositories = new DnsManagerRepostiory($params);
            $repositories->check();
        }
        catch (Exception $ex)
        {
            if ($ex instanceof FatalError)
            {
                $vars['fatalError'] = $ex->getMessage();
            }
            else
            {
                $vars['error'] = $ex->getMessage();
            }
        }
        return array(
            'tpl'  => 'dnsmanager',
            'vars' => $vars
        );
    }

    function getIPAddressesJSON($params)
    {
        try
        {
            $repositories = new DnsManagerRepostiory($params);
            return $repositories->getIPAddress();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    function getRDNSRecordsJSON($params)
    {
        try
        {
            $repositories = new DnsManagerRepostiory($params);
            return $repositories->getDNS();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    function saveRDNSJSON($params)
    {
        try
        {
            $repositories = new DnsManagerRepostiory($params);
            return ['success' => $repositories->saveDNS()];
        }
        catch (Exception $ex)
        {
            return ['errorMsg' => $ex->getMessage()];
        }
    }

    function deleteRDNSJSON($params)
    {
        try
        {
            $repositories = new DnsManagerRepostiory($params);
            return ['success' => $repositories->deleteDNS()];
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    function updateRDNSJSON($params)
    {
        try
        {
            $repositories = new DnsManagerRepostiory($params);
            return ['success' => $repositories->updateDNS()];
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

}
