<?php

namespace MGModule\EasyDCIM\Controllers\Server\Clientarea;

use Exception;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Exceptions\FatalError;
use MGModule\EasyDCIM\MgLibs\Process\AbstractController;
use MGModule\EasyDCIM\Repositories\Actions\AutoLogin;
use MGModule\EasyDCIM\Repositories\ClientDetails\ClientDetails;
use MGModule\EasyDCIM\Repositories\Console\Console;
use MGModule\EasyDCIM\Repositories\Console\NoVncConsole;
use MGModule\EasyDCIM\Repositories\Device\Device;
use MGModule\EasyDCIM\Repositories\Graphs\Graph;

/**
 * Description of home
 *
 * @author Michal Czech <michael@modulesgarden.com>
 */
class Home extends AbstractController
{

    /**
     * Get Client Area main page
     *
     * @param array $params, $vars
     * 
     * @return array
     */
    function indexHTML($params, $vars = [])
    {
        try
        {
            $repostiory = new ClientDetails($params);
            $vars       += $repostiory->getData();

        }
        catch (Exception $ex)
        {
            if ($ex instanceof FatalError)
            {
                $vars['fatalError'] = $ex->getMessage();
            }
            else
            {
                $vars['error'] = $ex->getMessage();
            }
        }
        return array(
            'tpl'  => 'home',
            'vars' => $vars
        );
    }

    /**
     * Get login link to Easy DCIM and redirect
     *
     * @param array $params 
     * @return mixed
     */
    function getLoginLinkHTML($params)
    {
        try
        {
            $repositories = new AutoLogin($params);
            $inf          = $repositories->getLink();
            header('Location: ' . $inf['redirectTo']);
            die();
        }
        catch (Exception $ex)
        {
            $vars = ['error' => $ex->getMessage()];
            return $this->indexHTML($params, $vars);
        }
    }

    /**
     * Get KVM Console
     *
     * @param array $params 
     * @return mixed
     * 
     */
    function getKVMConsoleHTML($params)
    {
        try
        {
            $repositories = new Console($params);
            $repositories->lunchConsole();
        }
        catch (Exception $ex)
        {
            $vars = ['error' => $ex->getMessage()];
            return $this->indexHTML($params, $vars);
        }
    }

    function downloadKeyHTML($params)
    {
        try
        {
            $repostiory = new ClientDetails($params);
            $repostiory->downloadKey();

        }
        catch (Exception $ex)
        {
            if ($ex instanceof FatalError)
            {
                $vars['fatalError'] = $ex->getMessage();
            }
            else
            {
                $vars['error'] = $ex->getMessage();
            }
        }
        return array(
            'tpl'  => 'home',
            'vars' => $vars
        );
    }

    function getNoVNCKVMConsoleJSON($params)
    {
        try
        {
            $repositories = new NoVncConsole($params);
            return $repositories->getRedirectLink();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /**
     * Power ON Service JSON
     *
     * @param array $params
     * 
     * @return array
     */
    public function powerOnJSON($params)
    {
        try
        {
            $repository = new Device($params);
            return $repository->powerOn();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /**
     * Power Off Service JSON
     *
     * @param array $params
     * 
     * @return array
     */
    public function powerOffJSON($params)
    {
        try
        {
            $repository = new Device($params);
            return $repository->powerOff();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /**
     * Reboot Service JSON
     *
     * @param array $params
     * 
     * @return array
     */
    public function rebootJSON($params)
    {
        try
        {
            $repository = new Device($params);
            return $repository->reboot();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }
    /**
     * Reboot Service JSON
     *
     * @param array $params
     *
     * @return array
     */
    public function coldResetJSON($params)
    {
        try
        {
            $repository = new Device($params);
            return $repository->coldReset();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /*
     * Change Hostname Action JSON
     * 
     * @param array $params
     * 
     * @return array
     * 
     */

    public function changeHostnameJSON($params)
    {
        try
        {
            $repository = new Device($params);
            return $repository->changeHostname();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    /*
     * Get Graps Action JSON
     * 
     * @param array $params
     * 
     * @return array
     * 
     */

    public function getGraphsJSON($params)
    {
        try
        {
            $repository = new Graph($params);
            return $repository->getCAGraphs();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

}
