<?php

namespace MGModule\EasyDCIM\Controllers\Server\Clientarea;

use Exception;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Exceptions\FatalError;
use MGModule\EasyDCIM\MgLibs\Process\AbstractController;
use MGModule\EasyDCIM\Repositories\Modules\UsageCollector as UsageCollectorRepository;

/**
 * Description of home
 *
 * @author Michal Czech <michael@modulesgarden.com>
 */
class UsageCollector extends AbstractController
{

    /**
     * Get Client Area main page
     *
     * @param array $params, $vars
     * 
     * @return array
     */
    function indexHTML($params, $vars = [])
    {
        try
        {
            $repositories = new UsageCollectorRepository($params);
            $vars         = $repositories->check();
        }
        catch (Exception $ex)
        {
            if ($ex instanceof FatalError)
            {
                $vars['fatalError'] = $ex->getMessage();
            }
            else
            {
                $vars['error'] = $ex->getMessage();
            }
        }
        return array(
            'tpl'  => 'usagecollector',
            'vars' => $vars
        );
    }

    /**
     * Get Graph and Bandwidth
     *
     * @param array $params, $vars
     * 
     * @return array
     */
    public function getGraphJSON($params)
    {
        try
        {
            $repositories = new UsageCollectorRepository($params);
            return $repositories->getGraph();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

    public function getBandwidthJSON($params)
    {
        try
        {
            $repositories = new UsageCollectorRepository($params);
            return $repositories->getBandwidth();
        }
        catch (Exception $ex)
        {
            return ['error' => $ex->getMessage()];
        }
    }

}
