<?php

use MGModule\EasyDCIM\Server;

if (!defined('DS'))
    define('DS', DIRECTORY_SEPARATOR);

/**
 * Include a autoloader.
 */
require_once __DIR__ . DS . 'vendor' . DS . 'autoload.php';

/**
 * Define module related meta data.
 *
 * Values returned here are used to determine module related abilities and
 * settings.
 *
 *
 * @return array
 */


function EasyDCIM_setAdditionalHeaders(){
    $path = \MGModule\EasyDCIM\Helpers\FileDir::getConfigDir() . DS . 'headers.json';
    $file = new \MGModule\EasyDCIM\MgLibs\FileReader\FileReader($path);
    $headers = $file->read();

    if(!is_null($headers) && $headers->enable === true){
        foreach($headers->headerList as $single){
            header($single);
        }
    }
}
function EasyDCIM_MetaData()
{
    return array(
        'DisplayName'              => 'EasyDCIM',
        'RequiresServer'           => true,
        'ServiceSingleSignOnLabel' => 'Log In To Panel',
    );
}

/**
 * WHMCS Config Options Page
 * 
 * @author Michal Czech <michael@modulesgarden.com>
 * @return array
 */
function EasyDCIM_ConfigOptions()
{
    if (!empty($_REQUEST['json']))
    {
        ob_clean();
        EasyDCIM_setAdditionalHeaders();
        echo Server::getJSONProductConfigPage($_REQUEST);
        die();
    }

    if ($_GET['action'] != 'save')
    {
        echo Server::getHTMLProductConfigPage($_REQUEST);
        die();
    }
}

/**
 * WHMCS Create Account
 * 
 * @author Michal Czech <michael@modulesgarden.com>
 * @param array $params
 * @return string
 */
function EasyDCIM_CreateAccount($params)
{
    return Server::accountAction('create', $params);
}

/**
 * WHMCS Terminate Account
 * 
 * @author Michal Czech <michael@modulesgarden.com>
 * @param array $params
 * @return string
 */
function EasyDCIM_TerminateAccount($params)
{
    return Server::accountAction('terminate', $params);
}

/**
 * WHMCS Suspend Account
 * 
 * @author Michal Czech <michael@modulesgarden.com>
 * @param array $params
 * @return string
 */
function EasyDCIM_SuspendAccount($params)
{
    return Server::accountAction('suspend', $params);
}

/**
 * WHMCS Unsuspend Account
 * 
 * @author Michal Czech <michael@modulesgarden.com>
 * @param array $params
 * @return string
 */
function EasyDCIM_UnsuspendAccount($params)
{
    return Server::accountAction('unsuspend', $params);
}

/**
 * WHMCS Change Password
 * 
 * @author Michal Czech <michael@modulesgarden.com>
 * @param array $params
 * @return string
 */
function EasyDCIM_ChangePassword($params)
{
    return Server::accountAction('changePassword', $params);
}

/**
 * WHMCS Admin Services Tab Function
 * 
 * @author Mateusz Pawlowski <mateusz.pa@modulesgarden.com>
 * @param array $params
 * @return array
 */
function EasyDCIM_AdminServicesTabFields($params)
{
    if (!empty($_REQUEST['json']))
    {
        ob_clean();
        EasyDCIM_setAdditionalHeaders();
        echo Server::getCustomJSONController($params, $_REQUEST);
        die();
    }
    return Server::getCustomHTMLController('Product', 'index', $params);
}

/**
 * WHMCS Usage Update 
 * 
 * @author Mateusz Pawlowski <mateusz.pa@modulesgarden.com>
 * @param $params
 * @return string
 */
function EasyDCIM_UsageUpdate($params)
{
    return Server::accountAction('usageUpdate', $params);
}

/**
 * WHMCS Service Single Sign On
 * 
 * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
 * @param array $params
 * @return array
 */
function EasyDCIM_ServiceSingleSignOn($params)
{
    return Server::getCustomHTMLController('Autologin', 'index', $params);
}

/**
 * WHMCS Server Test Connection
 * 
 * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
 * @param array $params
 * @return array
 */
function EasyDCIM_TestConnection($params)
{
    return Server::getCustomHTMLController('TestConnection', 'index', $params);
}

/**
 * WHMCS Custom Buttons
 * 
 * @param array $params
 * @return array
 */
function EasyDCIM_AdminCustomButtonArray($params)
{
    $buttonarray = array(
        "Update Order Information" => "UpdateOrder",
    );

    return $buttonarray;
}

/**
 * WHMCS Update Order
 * 
 * @param array $params
 * @return string
 */
function EasyDCIM_UpdateOrder($params)
{
    return Server::accountAction('synchronize', $params);
}

/**
 * WHMCS Client Area
 * 
 * @param array $params
 * @return array
 */
function EasyDCIM_ClientArea($params)
{
    if (!empty($_REQUEST['json']))
    {
        ob_clean();
        EasyDCIM_setAdditionalHeaders();
        echo Server::getJSONClientAreaPage($params, $_REQUEST);
        die();
    }
    return Server::getHTMLClientAreaPage($params, $_REQUEST);
}
