<?php

namespace MGModule\EasyDCIM\Helpers;

use Exception;
use MGModule\EasyDCIM\MgLibs\Database\Models\EmailTemplates;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Interfaces\IClient;
use MGModule\EasyDCIM\MgLibs\Lang;

/**
 * Description of Emails
 *
 * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
 */
class Emails
{

    /*
     * Send Email to selected WHMCS admins
     * 
     * @param integer $templateID object $client insteandof ClientAdapter
     */
    public static function sendServerCreateEmail($productID, $serviceID, $metadata = null)
    {
        $tempalteID = ProductConfiguration::getOne($productID, 'notificationServerCreate');
        $template   = EmailTemplates::where('id', $tempalteID)->first();

        $postData = [
            'messagename' => $template->name,
            'type'        => $template->type,
            'id'          => $serviceID,
        ];

        if(!is_null($metadata)){
            $postData['customvars'] =  self::prepareCustomVars($metadata);
        }

        self::sendUserEmail($postData);
    }

    /*
     * Send Email to selected WHMCS admins
     * 
     * @param integer $templateID object $client insteandof ClientAdapter
     */
    public static function sendEmailForSelectedAdmins($templateID, IClient $client)
    {
        $template = self::getTemplate($templateID);
        foreach ($client->getAdminis() as $admin)
        {
            $postData = [
                'messagename' => $template->name,
                'mergefields' => [
                    'service_id'         => $client->getServiceID(),
                    'easydcim_order_id'  => $client->getEasyOrderID(),
                    'easydcim_server_id' => self::getServerID($client)
                ]
            ];
            self::sendAdminEmail($postData, $admin);
        }
    }

    /*
     * Get Server ID and mute a error
     * 
     * @param object $client insteandof ClientAdapter
     * @return string
     */
    private static function getServerID(IClient $client)
    {
        try
        {
            return $client->getEasyServerID();
        }
        catch (Exception $ex)
        {
            return Lang::T('empty');
        }
    }

    /*
     * Get Cusotm Email template
     * 
     * @param integer $templateID
     * @throw error 
     */
    private static function getTemplate($templateID)
    {
        $template = EmailTemplates::where('id', $templateID)->first();
        if (is_null($templateID))
        {
            throw new Exception(Lang::T('templateNotFound'));
        }
        return $template;
    }

    /*
     * Send Email to Admin via WHMCS API
     * 
     * @param array $postData integer $admin
     * @throw API response error
     */
    private static function sendAdminEmail($postData = [], $admin = null)
    {
        $whmcsAPI = localAPI('SendAdminEmail', $postData, $admin);
        if ($whmcsAPI['result'] == "success")
        {
            return 'success';
        }
        throw new Exception($whmcsAPI['message']);
    }

    /*
     * Send Email to Admin via WHMCS API
     * 
     * @param array $postData integer $admin
     * @throw API response error
     */
    private static function sendUserEmail($postData = [], $admin = null)
    {
        $whmcsAPI = localAPI('SendEmail', $postData);
        if ($whmcsAPI['result'] == "success")
        {
            return 'success';
        }
        throw new Exception($whmcsAPI['message']);
    }

    /*
     * Prepare WHMCS custom vars string
     *
     * @param array $data
     * @return string
     */
    private static function prepareCustomVars($data){
        $prefix = "easydcim_";

        $newData = [];
        foreach($data as $key => $value){
            $newData[$prefix . strtolower(str_replace(' ', '_', $key))] = $value;
        }
        return base64_encode(serialize($newData));
    }

}
