<?php

namespace MGModule\EasyDCIM\Helpers;

use MGModule\EasyDCIM\MgLibs\Database\Models\MGProductConfiguration;

/**
 * Description of ConfigurableOptions
 *
 * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
 */
class ProductConfiguration
{
    /*
     * Get Modules Garden Product Configuration
     * 
     * @param integer $productID
     * @return array
     */

    public static function get($productID)
    {
        $fields = self::getFields($productID);
        return self::prepareToShow($fields);
    }

    /*
     * Get One Confiuration Field
     * 
     * @param integer $productID string $fieldName
     * @return array
     */

    public static function getOne($productID, $fieldName)
    {
        $fields = self::getField($productID, $fieldName);
        return self::isSerialized($fields->value);
    }

    /*
     * Set Fields 
     * 
     * @param integer $productID array $fields
     * @return void
     */

    public static function set($productID, $fields)
    {
        $field = self::prepareToSave($fields);
        foreach ($field as $key => $value)
        {
            self::saveField($productID, $key, $value);
        }
    }

    /*
     * Prepare array to save in database 
     * 
     * @param array $fields
     * @return array $fieldsArray
     */

    private static function prepareToSave($fields)
    {
        $fieldsArray = [];
        foreach ($fields as $key => $value)
        {
            if (is_array($value))
            {
                $value = serialize($value);
            }
            $fieldsArray[$key] = $value;
        }
        return $fieldsArray;
    }

    /*
     * Prepare array to show
     * 
     * @param array $fields
     * @return array $fieldsArray
     */

    private static function prepareToShow($fields)
    {
        $fieldsArray = [];
        foreach ($fields as $value)
        {
            $fieldsArray[$value->setting] = self::isSerialized($value->value);
        }
        return $fieldsArray;
    }

    /*
     * Check is string is serialized
     * 
     * #param string $value
     * @return mixed
     */

    private static function isSerialized($value)
    {
        return Serializer::isSerialized($value) ? unserialize($value) : $value;
    }

    /*
     * Update or Insert Field
     * 
     * @param integer $productID string $fieldName, $fieldValue
     * @return void
     */

    private static function saveField($productID, $fieldName, $fieldValue)
    {
        $field = self::getField($productID, $fieldName);
        if (is_null($field))
        {
            $field = self::createField($productID, $fieldName);
        }
        $field->value = $fieldValue;
        $field->save();
    }

    /*
     * Get field
     * 
     * @param integer $productID string $fieldName
     * @return object insteandof MGProductConfiguration
     */

    private static function getField($productID, $fieldName)
    {
        return MGProductConfiguration::where([
                    ['product_id', $productID],
                    ['setting', $fieldName],
                ])->first();
    }

    /*
     * Create Field
     * 
     * @param integer $productID string $fieldName
     * @return object insteandof MGProductConfiguration
     */

    private static function createField($productID, $fieldName)
    {
        $field             = new MGProductConfiguration();
        $field->product_id = $productID;
        $field->setting    = $fieldName;
        $field->save();
        return $field;
    }

    private static function getFields($productID)
    {
        return MGProductConfiguration::where('product_id', $productID)->get();
    }

}
