<?php

namespace MGModule\EasyDCIM\MgLibs\EasyDCIM\Adapters;

use MGModule\EasyDCIM\Helpers\ProductConfiguration;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Exceptions\FatalError;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Interfaces\IClient;

/**
 * Description of ClientAdapter
 *
 * @author Mateusz Pawłowski
 */
class ClientAdapter implements IClient
{
    /*
     * @var string $serverHostname
     */

    private $serverHostname;
    /*
     * @var string $serverAPIKey
     */
    private $serverAPIKey;
    /*
     * @var string $accountID
     */
    private $accountID;
    /*
     * @var integer $serviceID
     */
    private $serviceID;
    /*
     * @var integer $userID
     */
    private $userID;
    /*
     * @var string $domain
     */
    private $domain;
    /*
     * @var integer $username
     */
    private $username;
    /*
     * @var string $password
     */
    private $password;
    /*
     * @var string $firstName
     */
    private $firstName;
    /*
     * @var string $lastName
     */
    private $lastName;
    /*
     * @var string $fullName
     */
    private $fullName;
    /*
     * @var string $companyName
     */
    private $companyName;
    /*
     * @var string $email
     */
    private $email;
    /*
     * @var string $address1
     */
    private $address1;
    /*
     * @var string $address2
     */
    private $address2;
    /*
     * @var string $city
     */
    private $city;
    /*
     * @var string $fullState
     */
    private $fullState;
    /*
     * @var string $state
     */
    private $state;
    /*
     * @var string $postCode
     */
    private $postCode;
    /*
     * @var integer $countryCode
     */
    private $countryCode;
    /*
     * @var string $country
     */
    private $country;
    /*
     * @var string $phoneNumber
     */
    private $phoneNumber;
    /*
     * @var string $countryName
     */
    private $countryName;
    /*
     * @var string $productID
     */
    private $productID;


    /*
     * @var integer $locationID
     */
    private $locationID;

    /*
     * @var integer $modelID
     */
    private $modelID;

    /*
     * @var integer $osTemplate
     */
    private $osTemplate;

    /*
     * @var integer $bandwidth
     */
    private $bandwidth;
    /*
     * @var string $additionalIPAddress
     */
    private $additionalIPAddress;

    /*
     * @var string $hddSize
     */
    private $hddSize;
    /*
     * @var string $ssdSize
     */
    private $ssdSize;
    /*
     * @var string $ramSize
     */
    private $ramSize;
    /*
     * @var string $cpuCores
     */
    private $cpuCores;
    /*
     * @var string $hddModel
     */
    private $hddModel;
    /*
     * @var string $ssdModel
     */
    private $ssdModel;
    /*
     * @var string $ramModel
     */
    private $ramModel;
    /*
     * @var string $cpuModel
     */
    private $cpuModel;
    /*
     * @var boolean $acccessLevel
     */
    private $acccessLevel;

    /*
     * @var string $baseFeatures
     */
    private $baseFeatures;
    /*
     * @var string $caBaseFeatures
     */
    private $caBaseFeatures;
    /*
     * @var string $caSelectedGraphs
     */
    private $caSelectedGraphs;
    /*
     * @var string $caServerActions
     */
    private $caServerActions;
    /*
     * @var boolean $caSidebarActions
     */
    private $caSidebarActions;
    /*
     * @var boolean $caOsTemplate
     */
    private $caOsTemplate;
    /*
     * @var boolean $modules
     */
    private $modules;
    /*
     * @var array $suspendAction
     */
    private $suspendAction;
    /*
     * @var integer $suspendActionTemplate
     */
    private $suspendActionTemplate;
    /*
     * @var array $unsuspendAction
     */
    private $unsuspendAction;
    /*
     * @var integer $unsuspendActionTemplate
     */
    private $unsuspendActionTemplate;
    /*
     * @var array $terminateAction
     */
    private $terminateAction;
    /*
     * @var integer $terminateActiontemplate
     */
    private $terminateActiontemplate;
    /*
     * @var array $adminis
     */
    private $adminis;

    /*
     * @var integer $notificationServerCreate
     */
    private $notificationServerCreate;

    /*
     * @var integer $easyOrderID
     */
    private $easyOrderID;
    /*
     * @var integer $easyServerID
     */
    private $easyServerID;

    /**
     * Create Client Adapter
     * 
     * @param array $params
     */
    public function __construct($params)
    {
        /*
         * API Details Group
         */
        $this->serverHostname = $this->prepareHostname($params);
        $this->serverAPIKey   = $params['params']['serverpassword'];

        /*
         * Client Details Group
         */
        $this->accountID   = $params['params']['accountid'];
        $this->userID      = $params['params']['userid'];
        $this->domain      = $params['params']['domain'];
        $this->username    = $params['params']['username'];
        $this->password    = $params['params']['password'];
        $this->firstName   = $params['params']['clientsdetails']['firstname'];
        $this->lastName    = $params['params']['clientsdetails']['lastname'];
        $this->fullName    = $params['params']['clientsdetails']['fullname'];
        $this->companyName = $params['params']['clientsdetails']['companyname'];
        $this->email       = $params['params']['clientsdetails']['email'];
        $this->address1    = $params['params']['clientsdetails']['address1'];
        $this->address2    = $params['params']['clientsdetails']['address2'];
        $this->city        = $params['params']['clientsdetails']['city'];
        $this->fullState   = $params['params']['clientsdetails']['fullstate'];
        $this->state       = $params['params']['clientsdetails']['state'];
        $this->postCode    = $params['params']['clientsdetails']['postcode'];
        $this->countryCode = $params['params']['clientsdetails']['countrycode'];
        $this->country     = $params['params']['clientsdetails']['country'];
        $this->phoneNumber = $params['params']['clientsdetails']['phonenumber'];
        $this->countryName = $params['params']['clientsdetails']['countryname'];


        $this->productID = $params['params']['pid'];
        $this->serviceID = $params['params']['serviceid'];


        /*
         * Configuration Detials Group
         *
         */
        $porductConfig = ProductConfiguration::get($params['params']['pid']);


        $this->locationID               = (isset($params['params']['configoptions']['location'])) ? $params['params']['configoptions']['location']: $porductConfig['location'];
        $this->modelID                  = (isset($params['params']['configoptions']['model'])) ? $params['params']['configoptions']['model'] : $porductConfig['model'];
        $this->osTemplate               = (isset($params['params']['configoptions']['template'])) ? $params['params']['configoptions']['template'] : $porductConfig['osTemplate'];
        $this->bandwidth                = (isset($params['params']['configoptions']['bandwidth'])) ? $params['params']['configoptions']['bandwidth'] : $porductConfig['bandwidth'];
        $this->additionalIPAddress      = (isset($params['params']['configoptions']['additionalIpsNumber'])) ? $params['params']['configoptions']['additionalIpsNumber'] : $porductConfig['additionalIPAddress'];
        $this->hddSize                  = (isset($params['params']['configoptions']['hdd'])) ? $params['params']['configoptions']['hdd'] : $porductConfig['HDDSize'];
        $this->ssdSize                  = (isset($params['params']['configoptions']['ssd'])) ? $params['params']['configoptions']['ssd'] : $porductConfig['SSDSize'];
        $this->ramSize                  = (isset($params['params']['configoptions']['ram'])) ? $params['params']['configoptions']['ram'] : $porductConfig['RAMSize'];
        $this->cpuCores                 = (isset($params['params']['configoptions']['cpuCores'])) ? $params['params']['configoptions']['cpuCores'] : $porductConfig['CPUCores'];
        $this->baseFeatures             = $this->parseArray($porductConfig['baseFeatures']);
        $this->acccessLevel             = ($params['params']['configoptions']['serviceAccess']) ? $params['params']['configoptions']['serviceAccess'] : $porductConfig['serviceAccessLevel'];
        $this->hddModel                 = $porductConfig['HDDModel'];
        $this->ssdModel                 = $porductConfig['SSDModel'];
        $this->ramModel                 = $porductConfig['RAMModel'];
        $this->cpuModel                 = $porductConfig['CPUModel'];
        $this->caBaseFeatures           = $this->parseArray($porductConfig['caBaseFeatures']);
        $this->caSelectedGraphs         = $this->parseArray($porductConfig['caSelectedGraphs']);
        $this->caServerActions          = $this->parseArray($porductConfig['caServerActions']);
        $this->caSidebarActions         = $this->parseArray($porductConfig['caSidebarActions']);
        $this->caOsTemplate             = $this->parseArray($porductConfig['caOsTemplate']);
        $this->modules                  = $porductConfig['modules'];
        $this->suspendAction            = $porductConfig['suspendActions'];
        $this->suspendActionTemplate    = $porductConfig['templateSuspend'];
        $this->unsuspendAction          = $porductConfig['unsuspendActions'];
        $this->unsuspendActionTemplate  = $porductConfig['templateUnsuspend'];
        $this->terminateAction          = $porductConfig['terminateActions'];
        $this->terminateActiontemplate  = $porductConfig['templateTerminate'];
        $this->adminis                  = $porductConfig['notificationAdminId'];
        $this->notificationServerCreate = $porductConfig['notificationServerCreate'];

        /*
         * Custom Fields Group;
         */
        $this->easyOrderID  = $params['params']['customfields']['OrderID'];
        $this->easyServerID = $params['params']['customfields']['ServerID'];
    }

    /**
     * Prepare API Hostname
     * @param array $params
     * $return string
     */
    private function prepareHostname($params)
    {
        return 'http' . (($params['params']['serversecure'] == 'on') ? 's' : '') . '://' . (($params['params']['serverhostname']) ?: $params['params']['serverip']);
    }

    /*
     * Prepare compatibility array with Easy DCIM API
     * 
     * @param mixed
     * @retun mixed
     */

    private function parseArray($fieldArray)
    {
        if (is_array($fieldArray))
        {
            $field = [];
            foreach ($fieldArray as $value)
            {
                $field[$value] = 1;
            }
        }
        return ($field) ?: $fieldArray;
    }

    /**
     * EasyDCIM API Hostname
     * 
     * @return string
     */
    public function getServerHostname()
    {
        return $this->serverHostname;
    }

    /**
     * EasyDCIM API Token
     * 
     * @return string
     */
    public function getServerAPIKey()
    {
        return $this->serverAPIKey;
    }

    /**
     * WHMCS Account ID
     * 
     * @return integer
     */
    public function getAccountID()
    {
        return $this->accountID;
    }

    /**
     * WHMCS Service ID
     * 
     * @return integer
     */
    public function getServiceID()
    {
        return $this->serviceID;
    }

    /**
     * WHMCS User ID
     * 
     * @return integer
     */
    public function getUserID()
    {
        return $this->userID;
    }

    /**
     * WHMCS Hosting Domain
     * 
     * @return string
     */
    public function getDomain()
    {
        return $this->domain;
    }

    /**
     * WHMCS Hosting Username 
     * 
     * @return string
     */
    public function getUsername()
    {
        return $this->username;
    }

    /**
     * WHMCS Hosting Password 
     * 
     * @return string
     */
    public function getPassword()
    {
        return $this->password;
    }

    /**
     * WHMCS User first name
     * 
     * @return string
     */
    public function getFirstName()
    {
        return $this->firstName;
    }

    /**
     * WHMCS User last name
     * 
     * @return string
     */
    public function getLastName()
    {
        return $this->lastName;
    }

    /**
     * WHMCS User first and last name
     * 
     * @return string
     */
    public function getFullName()
    {
        return $this->fullName;
    }

    /**
     * WHMCS Company name
     * 
     * @return string
     */
    public function getCompanyName()
    {
        return $this->companyName;
    }

    /**
     * WHMCS User email address
     * 
     * @return string
     */
    public function getEmail()
    {
        return $this->email;
    }

    /**
     * WHMCS User address
     * 
     * @return string
     */
    public function getAddress1()
    {
        return $this->address1;
    }

    /**
     * WHMCS User address
     * 
     * @return string
     */
    public function getAddress2()
    {
        return $this->address2;
    }

    /**
     * WHMCS User city
     * 
     * @return string
     */
    public function getCity()
    {
        return $this->city;
    }

    /**
     * WHMCS User full state
     * 
     * @return string
     */
    public function getFullState()
    {
        return $this->fullState;
    }

    /**
     * WHMCS User state
     * 
     * @return string
     */
    public function getState()
    {
        return $this->state;
    }

    /**
     * WHMCS User post code
     * 
     * @return string
     */
    public function getPostCode()
    {
        return $this->postCode;
    }

    /**
     * WHMCS User country code
     * 
     * @return string
     */
    public function getCountryCode()
    {
        return $this->countryCode;
    }

    /**
     * WHMCS User country
     * 
     * @return string
     */
    public function getCountry()
    {
        return $this->country;
    }

    /**
     * WHMCS User phone number
     * 
     * @return string
     */
    public function getPhoneNumber()
    {
        return $this->phoneNumber;
    }

    /**
     * WHMCS User country name
     * 
     * @return string
     */
    public function getCountryName()
    {
        return $this->countryName;
    }

    /**
     * WHMCS Product ID
     * 
     * @return string
     */
    public function getProductID()
    {
        return $this->productID;
    }

    /**
     * Easy Location ID
     * 
     * @return integer
     */
    public function getLocationID()
    {
        return $this->locationID;
    }

    /**
     * Easy Model ID
     * 
     * @return integer
     */
    public function getModelID()
    {
        return $this->modelID;
    }

    /**
     * Easy auto accept setting
     * 
     * @return boolean
     */
    public function getAutoAccept()
    {
        return $this->autoAccept;
    }

    /**
     * Easy Acces Level
     * 
     * @return integer
     */
    public function getAcccessLevel()
    {
        return $this->acccessLevel;
    }

    /**
     * Easy activate suspend email template
     * 
     * @return boolean
     */
    public function getSuspendAction()
    {
        return $this->suspendAction[0];
    }

    /**
     * WHMCS Custom suspend email template ID
     * 
     * @return integer
     */
    public function getSuspendActionTemplate()
    {
        return $this->suspendActionTemplate;
    }

    /**
     * Easy activate unsuspend email template
     * 
     * @return boolean
     */
    public function getUnsuspendAction()
    {
        return $this->unsuspendAction[0];
    }

    /**
     * WHMCS Custom unsuspend email template ID
     * 
     * @return integer
     */
    public function getUnsuspendActionTemplate()
    {
        return $this->unsuspendActionTemplate;
    }

    /**
     * Easy activate terminate email template
     * 
     * @return boolean
     */
    public function getTerminateAction()
    {
        return $this->terminateAction[0];
    }

    /**
     * WHMCS Custom terminate email template ID
     * 
     * @return integer
     */
    public function getTerminateActiontemplate()
    {
        return $this->terminateActiontemplate;
    }

    /**
     * WHMCS Admin list who get actions emails
     * 
     * @return aray
     */
    public function getAdminis()
    {
        return $this->adminis;
    }

    /**
     * WHMCS Easy order ID
     * 
     * @throws FatalError insteadof Exception
     * @return integer
     */
    public function getEasyOrderID()
    {
        if (empty($this->easyOrderID))
        {
            throw new FatalError('orderIDISEmpty');
        }
        return $this->easyOrderID;
    }

    /**
     * WHMCS Easy server ID
     * 
     * @throws FatalError insteadof Exception
     * @return integer
     */
    public function getEasyServerID()
    {
        if (empty($this->easyServerID))
        {
            throw new FatalError('ServerIDIsEmpty');
        }
        return $this->easyServerID;
    }

    /**
     * Easy Os Template
     * 
     * @return integer
     */
    public function getOsTemplate()
    {
        return $this->osTemplate;
    }

    /**
     * Easy Bandwidth
     * 
     * @return integer
     */
    public function getBandwidth()
    {
        return $this->bandwidth;
    }

    /**
     * Easy Additional IP Addressess
     * 
     * @return string
     */
    public function getAdditionalIPAddress()
    {
        return $this->additionalIPAddress;
    }

    /**
     * Easy HDD Size
     * 
     * @return integer
     */
    public function getHddSize()
    {
        return $this->hddSize;
    }

    /**
     * Easy SSD Size
     * 
     * @return integer
     */
    public function getSsdSize()
    {
        return $this->ssdSize;
    }

    /**
     * Easy Ram Size
     * 
     * @return integer
     */
    public function getRamSize()
    {
        return $this->ramSize;
    }

    /**
     * Easy CPU Cores
     * 
     * @return integer
     */
    public function getCpuCores()
    {
        return $this->cpuCores;
    }

    /**
     * Easy Hdd Model ID
     * 
     * @return integer
     */
    public function getHddModel()
    {
        return $this->hddModel;
    }

    /**
     * Easy SSD Model
     * 
     * @return integer
     */
    public function getSsdModel()
    {
        return $this->ssdModel;
    }

    /**
     * Easy Ram Model ID
     * 
     * @return integer
     */
    public function getRamModel()
    {
        return $this->ramModel;
    }

    /**
     * Easy CPU Model ID
     * 
     * @return integer
     */
    public function getCpuModel()
    {
        return $this->cpuModel;
    }

    /**
     * System Base Features
     * 
     * @return integer
     */
    public function getBaseFeatures()
    {
        return $this->baseFeatures;
    }

    /**
     * Client Area Base Features
     * 
     * @return integer
     */
    public function getCaBaseFeatures()
    {
        return $this->caBaseFeatures;
    }

    /**
     * Client Area Selected Graphs
     * 
     * @return integer
     */
    public function getCaSelectedGraphs()
    {
        return $this->caSelectedGraphs;
    }

    /**
     * Client Area Server Actions
     * 
     * @return integer
     */
    public function getCaServerActions()
    {
        return $this->caServerActions;
    }

    /**
     * Client Sidebar Actions
     * 
     * @return integer
     */
    public function getCaSidebarActions()
    {
        return $this->caSidebarActions;
    }

    /**
     * Client Area available os tempaltes
     * 
     * @return integer
     */
    public function getCaOsTemplate()
    {
        return $this->caOsTemplate;
    }

    /**
     * Client Area Base Features
     * 
     * @return integer
     */
    public function getModules()
    {
        return $this->modules;
    }

    /**
     * Email Notifictaion
     * 
     * @return integer
     */
    public function getNotificationServerCreate()
    {
        return $this->notificationServerCreate;
    }

}
