<?php

namespace MGModule\EasyDCIM\MgLibs\EasyDCIM;

use Exception;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\API\Connection;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Interfaces\IClient;

/**
 * Description of EasyDCIM
 *
 * @author Mateusz Pawłowski
 * 
 * @property string $device
 * @property string $graph
 * @property string $locations
 * @property string $models
 * @property string $order
 * @property string $service
 * @property string $system
 * @property string $user
 * @property string $os 
 * @property string $ipmi
 * @property string $dnsManager
 */
class EasyDCIM
{

    /**
     * ClientAdapter object
     * 
     * @var object insteadof ClientAdapter
     */
    private $params;

    /**
     * Connection object
     * 
     * @var object insteadof Connection
     */
    private $api;

    /**
     * Easy DCIM Create ClientAdaper
     * 
     * @param $client
     */
    public function __construct(IClient $client)
    {
        $this->params = $client;
    }

    /**
     * 
     * Easy DCIM Set API Connection and Validate required fields
     * 
     */
    private function setAPI()
    {
        if (!$this->params->getServerHostname())
        {
            throw new Exception('API: Server IP and hostname is empty.');
        }
        if (!$this->params->getServerAPIKey())
        {
            throw new Exception('API: Server API Key is empty.');
        }
        $this->api = new Connection($this->params->getServerHostname(), $this->params->getServerAPIKey(), $this->params->getProductID());
    }

    /*
     * Easy DCIM API magic method handling
     * 
     * @param string
     * @return object
     */
    public function __get($function)
    {
        return $this->getClass($function);
    }

    /*
     * Easy DCIM API method handling
     * 
     * @param string
     * @return object
     */
    public function getClass($function)
    {
        if (is_null($function))
        {
            throw new Exception('API: The method cannot be empty.');
        }
        $className = __NAMESPACE__ . '\API\\' . ucfirst($function);
        if (!class_exists($className))
        {
            throw new Exception('API: Class ' . ucfirst($function) . ' does not exists.');
        }

        $this->setAPI();
        return new $className($this->api, $this->params);
    }

}
