<?php

namespace MGModule\EasyDCIM\MgLibs\FileReader;

use Exception;

/**
 * Description of FileReader
 *
 * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
 */
class FileReader
{
    /*
     * File directory
     * @var string $filePath
     */

    protected $filePath;
    /*
     * File name
     * @var string $fileName
     */
    protected $fileName;

    /*
     * Save file directory and get file name
     * @param string $file
     */

    public function __construct($file)
    {
        $this->filePath = $file;
        $path           = explode('/', $file);
        $this->fileName = end($path);
    }

    /*
     * Check file is JSON and Read
     * 
     * @param string $file
     * @return JSON object 
     */

    public function read()
    {
        if ($this->isJOSN())
        {
            return $this->openFile();
        }
    }

    /*
     * Open JSON file
     * 
     * @return JSON object 
     * @throw string error 
     */

    private function openFile()
    {
        if (file_exists($this->filePath))
        {
            $file = file_get_contents($this->filePath);

            $response = json_decode($file);
            if (json_last_error() !== 0)
            {
                throw new Exception('File reader - file: ' . $this->filePath . ' message: ' . json_last_error_msg());
            }
            return $response;
        }
    }

    /*
     * Get file type
     * 
     * @return string $type
     * 
     */

    private function getType()
    {
        $fileName = explode(".", $this->fileName);
        if (is_array($fileName))
        {
            return strtolower(end($fileName));
        }
        return strtolower($fileName);
    }

    /*
     * Check is JSON file
     * 
     * @return string $type
     * 
     */

    private function isJOSN()
    {
        $type = $this->getType();

        if (!is_null($type) && $type == "json")
        {
            return true;
        }
    }

}
