<?php

namespace MGModule\EasyDCIM\MgLibs\Hooks;

use Exception;
use MGModule\EasyDCIM\Helpers\Logs;
use MGModule\EasyDCIM\MgLibs\FileReader\FileReader;
use MGModule\EasyDCIM\MgLibs\Hooks\HooksManager;

/**
 * Description of HooksManager
 *
 * @author Mateusz Pawłowski
 */
class HooksManager
{

    /**
     * Hooks to register
     * 
     * @var array
     */
    private $hookRegister = [];

    /**
     * Hooks files
     * 
     * @var array
     */
    private $files = [];

    /**
     * Hooks path
     * 
     * @var array
     */
    private $path;

    /**
     * Hooks configuration
     * 
     * @var array
     */
    protected $config;

    /**
     * Current hook name
     * 
     * @var array
     */
    private static $currentName;

    /**
     * Set a hooks directory
     * 
     * 
     * @param string $moduleDIR 
     */
    public function __construct($moduleDIR)
    {
        $this->path = $moduleDIR . DS . 'Hooks';
    }

    /**
     * Add available hooks
     * 
     * @param string $moduleDIR
     */
    public static function addHooks($moduleDIR)
    {
        try
        {
            $hooksManager = new HooksManager($moduleDIR);
            $hooksManager->getHooksConfig($moduleDIR);
            $hooksManager->getFiles();
            $hooksManager->getHooks();
            $hooksManager->run();
        }
        catch (Exception $ex)
        {
            Logs::save('HookRegister', 'Fatal Error', $ex->getMessage());
        }
    }

    /**
     * Add Hook to registers
     * 
     * @param string $moduleDIR integer $sort
     */
    public function register($callback, $sort = 1)
    {
        $this->hookRegister[] = [
            "name"     => self::$currentName,
            "function" => $callback,
            "sort"     => $sort
        ];
    }

    /**
     * Include available hooks file
     * 
     */
    private function getHooks()
    {
        foreach ($this->files as $hook)
        {
            try
            {
                self::$currentName = explode(".", $hook)[0];
                require $this->path . DS . $hook;
            }
            catch (Exception $ex)
            {
                Logs::save('HookRegister', $hook, $ex->getMessage());
            }
        }
    }

    /**
     * Get available hook files 
     * 
     */
    private function getFiles()
    {

        $files = scandir($this->path);
        foreach ($files as $key => $hookFile)
        {
            if ($hookFile == "." || $hookFile == "..")
            {
                unset($files[$key]);
            }
        }
        $this->files = $files;
    }

    /**
     * Get hooks json configuration file
     * 
     */
    private function getHooksConfig($moduleDIR)
    {
        $hooksFilePath = $moduleDIR . DS . 'Config' . DS . 'hooks.json';
        $file          = new FileReader($hooksFilePath);
        $hooksConfig   = $file->read();

        $this->config = $hooksConfig->hooks;
    }

    /**
     * Register all activated hooks
     * 
     */
    private function run()
    {

        foreach ($this->hookRegister as $hook)
        {
            if ($this->config->{$hook['name']})
            {
                add_hook(
                        $hook['name'], $hook['sort'], $hook['function']
                );
            }
        }
    }

}
