<?php

namespace MGModule\EasyDCIM\MgLibs\Models;

use MGModule\EasyDCIM\MgLibs\Lang;
use MGModule\EasyDCIM\MgLibs\Smarty;
use MGModule\EasyDCIM\Server;

/**
 * Description of RepositoryAbstract
 *
 * @author Mateusz Pawłowski
 */
abstract class AbstractRepository
{

    /**
     * WHMCS params
     * 
     * @var array 
     */
    protected $params;

    /**
     * Configuration Errors
     * 
     * @var array 
     */
    private $registredValidationErros = [];

    /**
     * Assign params to $params
     * 
     * @params array $params
     */
    public function __construct($params = [])
    {
        $this->params = $params;
    }

    /**
     * Table parseROW
     * 
     * @param string $template, array $data
     * @return HTML template
     */
    protected function tableParseRow($template, $data)
    {

        if (is_object($data))
        {
            $data = get_object_vars($data);
        }

        return Smarty::I()->view($template, $data);
    }

    /**
     * DataTable  parseRow
     * 
     * @param string $template, array $data
     * @return array
     */
    protected function dataTablesParseRow($template, $data)
    {


        $row    = $this->tableParseRow($template, $data);
        $output = [];
        if (preg_match_all('/\<td\>(?P<col>.*?)\<\/td\>/s', $row, $result))
        {
            foreach ($result['col'] as $col)
            {
                $output[] = $col;
            }
        }
        return $output;
    }

    /**
     * Register Error in Form Builder 
     * 
     * @param array $errors
     */
    protected function registerErrors($errors)
    {
        $this->registredValidationErros = $errors;
    }

    /**
     * 
     * Add Error in Form Builder 
     * 
     * @param string $field, string $langspace
     * @return string
     */
    protected function getFieldError($field, $langspace = 'validationErrors')
    {
        if (!isset($this->registredValidationErros[$field]))
        {
            return false;
        }

        $message = [];
        foreach ($this->registredValidationErros[$field] as $type)
        {
            $message[] = Lang::absoluteT($langspace, $type);
        }

        return implode(',', $message);
    }

    /**
     * 
     * Parse tpl Files to String
     * 
     * @param string $templateName, $templatePath array $vars
     * @return string
     */
    protected function parseTemplateToString($tempalteName, $tempaltePath, $vars = [])
    {
        $dir = Server::getModuleTemplatesDir();
        return Smarty::I()->view($tempalteName, $vars, $dir . $tempaltePath);
    }

}
