<?php

namespace MGModule\EasyDCIM\MgLibs\Process;

use MGModule\EasyDCIM\Helpers\FileDir;
use MGModule\EasyDCIM\MgLibs\Database\Interfaces\IMigrations;
use const DS;

/**
 * Description of Install
 *
 * @author Mateusz Pawłowski
 */
class Migrations
{
    /*
     * Main module namespace
     * 
     * @var string
     */

    private $mainNamespace;

    /*
     * Migartion Files Path;
     * 
     * @var string
     */
    private $path;

    /*
     * Migration Files
     * 
     * @var array
     */
    private $migrationClasses;

    /*
     * Set a main namespace when create class 
     * 
     * @param namespace $mainNamespace
     */

    public function __construct($mainNamespace)
    {
        $this->mainNamespace = $mainNamespace;
    }

    /*
     * Prepare and run migration
     * 
     * @return void
     */

    public function run()
    {
        $this->setPath();
        $this->setMigrationClasses();
        $this->runMigrate();
    }

    /*
     * Prepare and remove migration
     * 
     * @return void
     */

    public function remove()
    {
        $this->setPath();
        $this->setMigrationClasses();
        $this->removeMigrate();
    }

    /*
     * Run migration to create required database tables
     * 
     * @return void
     */

    private function runMigrate()
    {
        foreach ($this->migrationClasses as $migrationClass)
        {
            $class  = $this->mainNamespace . '\MgLibs\Database\Migrations\\' . $migrationClass;
            $object = new $class;
            if ($object instanceof IMigrations)
            {
                $object->up();
            }
        }
    }

    /*
     * Run migration to remove database tables
     * 
     * @return void
     */

    private function removeMigrate()
    {
        foreach ($this->migrationClasses as $migrationClass)
        {
            $class  = $this->mainNamespace . '\MgLibs\Database\Migrations\\' . $migrationClass;
            $object = new $class;
            if ($object instanceof IMigrations)
            {
                $object->down();
            }
        }
    }

    /*
     * Set Migraion files path
     * 
     */

    private function setPath()
    {
        $this->path = FileDir::getModuleDIR() . DS . 'MgLibs' . DS . 'Database' . DS . 'Migrations';
    }

    /*
     * Set migraion Classes name
     * 
     */

    private function setMigrationClasses()
    {
        $migrationClasses = [];
        foreach ($this->getMigrationsFiles() as $key => $value)
        {
            $migrationClasses[] = explode('.', $value)[0];
        }
        $this->migrationClasses = $migrationClasses;
    }

    /*
     * Get migration files 
     * 
     * @return array $files
     * 
     */

    private function getMigrationsFiles()
    {

        $files          = scandir($this->path);
        $migrationClass = [];
        foreach ($files as $key => $hookFile)
        {
            if ($hookFile == "." || $hookFile == "..")
            {
                unset($files[$key]);
            }
        }
        return $files;
    }

}
