<?php
namespace MGModule\EasyDCIM\Repositories\Actions;

use Exception;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Adapters\ClientAdapter;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\EasyDCIM;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Interfaces\IClient;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Models\Users\UserDetails;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Models\Users\UserLoginData;
use MGModule\EasyDCIM\MgLibs\Lang;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;



/**
 * Description of Suspend
 *
 * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
 */
class AutoLogin extends AbstractRepository
{

    /**
     * Check user and get Auto Login link to Easy DCIM
     * 
     * @return array
     * @throw error
     */
    public function getLink()
    {
        $client = new ClientAdapter($this->params);
        $check  = $this->checkUserExists($client);

        if (!empty($check->user->id))
        {
            $link = $this->preapareLink($client, $check->user->id);
            return [
                'success'    => true,
                'redirectTo' => $link->link
            ];
        }
        throw new Exception(Lang::T('accountNoExists'));
    }

    /**
     * Check is user exists
     * 
     * @param object $client insteandof ClientAdapter
     * @return JSON object
     */
    private function checkUserExists(IClient $client)
    {
        $userDetails = new UserDetails();
        $userDetails->setEmail($client->getEmail());
        $api         = new EasyDCIM($client);
        return $api->user->checkIfExists($userDetails);
    }

    /**
     * Get Auto Login link to Easy DCIM
     * 
     * @param object $client insteandof ClientAdapter, integer $easyClientID
     * @return JSON object
     */
    public function preapareLink(IClient $client, $easyClientID)
    {
        $api       = new EasyDCIM($client);

        $userModel = new UserLoginData();
        $userModel->setId($easyClientID)
            ->setEmail($client->getEmail())
            ->setPath('services/' . $this->getServiceID($api) . '/summary');

        return $api->user->getKeyLogin($userModel);
    }

    public function getServiceID(EasyDCIM $api)
    {
        $device = $api->device->getInformation();

        return $device->order->service->id;
    }
}
