<?php

namespace MGModule\EasyDCIM\Repositories\Actions;

use Exception;
use MGModule\EasyDCIM\Helpers\CustomFields;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Adapters\ClientAdapter;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\EasyDCIM;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Interfaces\IClient;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Models\Devices\Metadata;
use MGModule\EasyDCIM\MgLibs\Lang;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;

/**
 * Description of Suspend
 *
 * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
 */
class ChangePassword extends AbstractRepository
{
    /*
     * Change SSH and Root Password in Easy DCIM
     * 
     * 
     * @throw Exception 
     */

    public function change()
    {
        $client = new ClientAdapter($this->params);
        $this->checkCusomFields();
        $this->setSSHPassword($client);
        $this->setRootPassword($client);
    }

    /*
     * Check is custom field is not empty
     * 
     * @throw Exception 
     */

    public function checkCusomFields()
    {
        if (empty(CustomFields::get($this->params['params']['packageid'], $this->params['params']['serviceid'], 'OrderID')))
        {
            throw new Exception(Lang::T('orderIDIsEmpty'));
        }
        if (empty(CustomFields::get($this->params['params']['packageid'], $this->params['params']['serviceid'], 'ServerID')))
        {
            throw new Exception(Lang::T('serverIDIsEmpty'));
        }
    }

    /*
     * Set SSH Password in Easy DCIM
     * 
     * @param object $client insteandof ClientAdapter
     * @throw Exception API Error
     */

    private function setSSHPassword(IClient $client)
    {
        $metadataModel = new Metadata();
        $metadataModel->setSlug('ssh.password')
                ->setValue($this->params['params']['password']);

        $api = new EasyDCIM($client);
        $api->device->assignMetadata($metadataModel);
    }

    /*
     * Set Root Password in Easy DCIM
     * 
     * @param object $client insteandof ClientAdapter
     * @throw Exception API Error
     */

    private function setRootPassword(IClient $client)
    {
        $metadataModel = new Metadata();
        $metadataModel->setSlug('ssh-root-password')
                ->setValue($this->params['params']['password']);

        $api = new EasyDCIM($client);
        $api->device->assignMetadata($metadataModel);
    }

}
