<?php

namespace MGModule\EasyDCIM\Repositories\Actions;

use MGModule\EasyDCIM\Helpers\CustomFields;
use MGModule\EasyDCIM\Helpers\Emails;
use MGModule\EasyDCIM\MgLibs\Database\Models\Hostings;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Adapters\ClientAdapter;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\EasyDCIM;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;

/**
 * Description of Suspend
 *
 * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
 */
class Synchronize extends AbstractRepository
{
    /*
     * Synchronzie Easy and WHMCS accounts
     * 
     */

    public function synchronize()
    {
        $info = $this->getOrderInformation();

        if (!empty($info->service->related_id))
        {
            $device = $this->getDeviceInformation($info->service->related_id);

            $this->saveDedicatedIP($device);
            CustomFields::set($this->params['params']['packageid'], $this->params['params']['serviceid'], 'ServerID', $info->service->related_id);
            Emails::sendServerCreateEmail($this->params['params']['packageid'], $this->params['params']['serviceid'], $device->metadata);
        }
    }

    /**
     * Get Order Information
     * 
     * @return JSON Object
     */
    protected function getOrderInformation()
    {
        $api = new EasyDCIM(new ClientAdapter($this->params));

        return $api->order->getOrder();
    }

    /*
     * Get Easy DCIM device inforamtion
     * 
     * @param string $deviceID
     * @return JSON object
     * @throw Exception API Error
     */

    public function getDeviceInformation($deviceID)
    {
        $api = new EasyDCIM(new ClientAdapter($this->params));
        return $api->device->getInformation($deviceID);
    }

    /*
     * Save DedicatedID from Easy dCIM
     * 
     * @param JSON object $device 
     * @throw Exception API Error
     */

    private function saveDedicatedIP($device)
    {
        $hosting = Hostings::where('id', $this->params['params']['serviceid'])->update([
            'dedicatedip' => $device->metadata->{'IP Address'},
            'assignedips' => $device->metadata->{'Additional IP Addresses'}
        ]);
    }

}
