<?php

namespace MGModule\EasyDCIM\Repositories\Console;

use Exception;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Adapters\ClientAdapter;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\EasyDCIM;
use MGModule\EasyDCIM\MgLibs\Lang;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;
use MGModule\EasyDCIM\Repositories\Console\Traits\Ipmi;

/**
 * Description of GraphF
 *
 * @author Mateusz Pawłowski
 */
class Console extends AbstractRepository
{
    use Ipmi;
    /*
     * Get KVM Console Details
     * 
     * @retur JSON object
     * @throw \Exception
     */

    public function getDetails()
    {
        $client = new ClientAdapter($this->params);
        $api    = new EasyDCIM($client);

        return $api->ipmi->getConsoleDetails();
    }

    /*
     * Get KVM Console
     * 
     * @return jnlp file
     * @throw \Exception
     */

    public function lunchConsole()
    {
        $client  = new ClientAdapter($this->params);
        $api     = new EasyDCIM($client);

        if($this->checkIsIPMIEnable($api) == false){
            throw new \Exception(Lang::absoluteT('IpmiNotEnable'));
        }

        $console = $api->ipmi->lunchConsole();

        $res = @json_decode($console);
        if (isset($res->status) && $res->status == 'error')
        {
            throw new Exception(isset($res->message) ? $res->message : Lang::T('unableToLunchConsole'));
        }

        header('Content-type: application/x-java-jnlp-file');
        header('Content-Disposition: inline; filename=launch.jnlp');
        header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Date in the past
        header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
        header("Cache-Control: no-store, no-cache, must-revalidate");
        header("Cache-control: post-check=0, pre-check=0, false");
        header("Pragma: no-cache");
        header("Content-Type: application/x-java-jnlp-file");
        echo $console;
        die();
    }

}
