<?php

namespace MGModule\EasyDCIM\Repositories\Device;

use Exception;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Adapters\ClientAdapter;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\EasyDCIM;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Models\Devices\Metadata;
use MGModule\EasyDCIM\MgLibs\Lang;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;

/**
 * Description of Device
 *
 * @author Mateusz Pawłowski
 */
class Device extends AbstractRepository
{

    public function powerOn()
    {
        $client = new ClientAdapter($this->params);
        $api    = new EasyDCIM($client);
        $api->device->powerOn();
        return ['success' => Lang::T('powerOnSuccess')];
    }

    public function powerOff()
    {
        $client = new ClientAdapter($this->params);
        $api    = new EasyDCIM($client);
        $api->device->powerOff();
        return ['success' => Lang::T('powerOffSuccess')];
    }

    public function reboot()
    {
        $client = new ClientAdapter($this->params);
        $api    = new EasyDCIM($client);
        $api->device->reboot();
        return ['success' => Lang::T('rebootSuccess')];
    }

    public function coldReset()
    {
        $client = new ClientAdapter($this->params);
        $api    = new EasyDCIM($client);
        $api->ipmi->coldReset();
        return ['success' => Lang::T('coldResetSuccess')];
    }

    public function changeHostname()
    {
        if (empty($this->params['hostname']))
        {
            throw new Exception(Lang::T('hostnameCanNotEmpty'));
        }
        $metadataModel = new Metadata();
        $metadataModel->setSlug('hostname')
                ->setValue($this->params['hostname']);
        $client        = new ClientAdapter($this->params);
        $api           = new EasyDCIM($client);
        $api->device->assignMetadata($metadataModel);

        return['success' => sprintf(Lang::T('hostnameChanged'), $this->params['hostname'])];
    }

}
