<?php

namespace MGModule\EasyDCIM\Repositories\Graphs;

use Carbon\Carbon;
use MGModule\EasyDCIM\Helpers\FileDir;
use MGModule\EasyDCIM\Helpers\ProductConfiguration;
use MGModule\EasyDCIM\MgLibs\Database\Models\Hostings;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Adapters\ClientAdapter;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\EasyDCIM;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Exceptions\FatalError;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Models\Devices as DeviceModel;
use MGModule\EasyDCIM\MgLibs\FileReader\FileReader;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;
use const DS;

/**
 * Description of Graph
 *
 * @author Mateusz Pawłowski
 */
class Graph extends AbstractRepository
{
    /*
     * Get Admin Area Graphs 
     * 
     * @return array
     */


    public function getClientTraffic($width, $height, $startDate = null, $endDate = null)
    {


        $nowTime = Carbon::now();
        if (is_null($startDate) || is_null($endDate))
        {
            $date      = $this->getDate();
            $endDate   = $date['endDate']->setTime($nowTime->format('H'),$nowTime->format('i'),$nowTime->format('s'))->getTimestamp();
            $startDate = $date['startDate']->setTime(0,0,1)->getTimestamp();
        }else{
            if($nowTime->format('j')  == explode('-', $endDate)[2]){
                $endDate = Carbon::parse($endDate)->setTime($nowTime->format('H'),$nowTime->format('i'),$nowTime->format('s'))->getTimestamp();
            }else{
                $endDate = Carbon::parse($endDate)->setTime(23,59,59)->getTimestamp();
            }
            $startDate = Carbon::parse($startDate, 'UTC')->setTime(0,0,1)->getTimestamp();
        }

        $client     = new ClientAdapter($this->params);
        $graphModel = new DeviceModel\Graph();
        $graphModel
            ->setType('UserAggregateTraffic')
            ->setStart($startDate)
            ->setEnd($endDate)
            ->setWidth($width)
            ->setHeight($height);


        $api        = new EasyDCIM($client);
        $userId = $api->device->getInformation()->user_id;
        $image      = $api->graph->getUserGraph($graphModel, $userId);
        return $this->checkAndRenderGraph($image);
    }


    public function getAAGraphs()
    {
        $vars = [];
        foreach ($this->getAvailableGraphs() as $key => $value)
        {
            $vars['graphs'][] = $this->getGraph($value, 1150, 300, $this->params['startDate'], $this->params['endDate']);
        }
        return $vars;
    }

    public function getCAGraphs()
    {
        $vars = [];

        $availableGraphs = $this->getCAAvailableGraphsList();
        foreach ($availableGraphs as $key => $value)
        {
            $vars['graphs'][] = $this->getGraph($value, 740, 300, $this->params['startDate'], $this->params['endDate']);
        }
        return $vars;
    }

    public function getCAAvailableGraphsList()
    {
        $graphs = $this->getAvailableGraphs();
        $config = $this->getProductConfiguration();
        return array_intersect($graphs, $config['caSelectedGraphs']);
    }

    public function getGraph($type, $width, $height, $startDate = null, $endDate = null)
    {

        $nowTime = Carbon::now();
        if (is_null($startDate) || is_null($endDate))
        {
            $date      = $this->getDate();
            $endDate   = $date['endDate']->setTime($nowTime->format('H'),$nowTime->format('i'),$nowTime->format('s'))->getTimestamp();
            $startDate = $date['startDate']->setTime(0,0,1)->getTimestamp();
        }else{
            if($nowTime->format('j')  == explode('-', $endDate)[2]){
                $endDate = Carbon::parse($endDate)->setTime($nowTime->format('H'),$nowTime->format('i'),$nowTime->format('s'))->getTimestamp();
            }else{
                $endDate = Carbon::parse($endDate)->setTime(23,59,59)->getTimestamp();
            }
            $startDate = Carbon::parse($startDate, 'UTC')->setTime(0,0,1)->getTimestamp();
        }

        $client     = new ClientAdapter($this->params);
        $graphModel = new DeviceModel\Graph();
        $graphModel->setType($type)
                ->setStart($startDate)
                ->setEnd($endDate)
                ->setWidth($width)
                ->setHeight($height);
        $api        = new EasyDCIM($client);
        $image      = $api->device->renderGraphs($graphModel);
        return $this->checkAndRenderGraph($image);
    }

    protected function getStartDateIFDifferenceIsOver(Carbon $startDate, $days = 30){
        $endDate = Carbon::now();
        if($startDate->diffInDays($endDate) > $days){
            return $endDate->subDays($days);
        }
        return $startDate;
    }

    /*
     * Check And Render Graph
     * 
     * @return string
     */

    protected function checkAndRenderGraph($encodedGraph)
    {
        if (base64_decode($encodedGraph, true))
        {
            return 'data: image/png;base64,' . $encodedGraph;
        }
    }

    /*
     * Get max Date range
     * 
     * @return array
     */


    public function getDateMaxRange()
    {
        $this->checkServerIDField();
        $hosting   = $this->getHosting();
        $startDate = Carbon::parse($hosting->regdate);
        $endDate   = Carbon::now();

        return [
            'startDate' => $startDate,
            'endDate'   => $endDate
        ];
    }

    public function getDate()
    {
        $this->checkServerIDField();
        $hosting        = $this->getHosting();
        $startModel     = Carbon::parse($hosting->regdate);
        $endModel   = Carbon::now();

        $startDate = $this->getStartDateIFDifferenceIsOver($startModel);

        return [
            'startDate' => $startDate,
            'endDate'   => $endModel
        ];
    }
    /*
     * Get display Date range
     *
     * @return array
     */
    public function getDisplayDate()
    {
        $data = $this->getDate();

        return [
            'startDisplayDate' => $data['startDate']->format('Y-m-d'),
            'endDisplayDate'   => $data['endDate']->format('Y-m-d'),
        ];
    }

    public function getDateMax()
    {
        $data = $this->getDateMaxRange();

        return [
            'startMaxDate' => $data['startDate']->format('Y-m-d'),
            'endMaxDate'   => $data['endDate']->format('Y-m-d'),
        ];
    }

    /*
     * Get Date range for Ajax request
     * 
     * @return array
     */

    public function getDataRange()
    {
        if(isset($this->params['startDate']) && isset($this->params['endDate']))
        {
            $startDate  = Carbon::parse($this->params['startDate'])->setTime(0,0,1);
            $endDate    = Carbon::parse($this->params['endDate']);
        }else {
            $maxDataRange = $this->getDate();
            $startDate  = $maxDataRange['startDate']->setTime(0,0,1);;
            $endDate    = $maxDataRange['endDate'];
        }

        return [
            'startDate' => $startDate,
            'endDate'   => $endDate
        ];
    }

    /*
     * Get Hosting
     * 
     * @return object insteandof Hostings
     */

    protected function getHosting()
    {
        return Hostings::where('id', $this->params['params']['serviceid'])->first();
    }

    /*
     * Check Server ID is not empty
     * 
     * @throw error
     */

    protected function checkServerIDField()
    {

        if (empty($this->params['params']['customfields']['ServerID']))
        {
            throw new FatalError('ServerIDIsEmpty');
        }
    }

    /*
     * Get activated graph in EasyDCIM
     * 
     * @return JSON 
     */

    public function getGraphInEasy()
    {
        $client = new ClientAdapter($this->params);
        $api    = new EasyDCIM($client);
        return $api->device->getAvailableGraphs();
    }

    /*
     * Get avaiable in WHMCS & Easy graphs
     * 
     * @return array
     */

    public function getAvailableGraphs()
    {
        $config                      = $this->getConfigFile();
        $graphs                      = $this->getGraphInEasy();
        $graphs                      = array_flip(json_decode(json_encode($graphs), true));
        //Put Aggregate Traffic 
        $graphs['Aggregate Traffic'] = "AggregateTraffic";
        return array_intersect($graphs, $config->graphs->available);
    }

    /**
     * Get Configuration file
     *
     * @return JSON object
     */
    private function getConfigFile()
    {
        $file = new FileReader(FileDir::getConfigDir() . DS . 'configuration.json');
        return $file->read();
    }

    /**
     * Get MG Product configuration
     *
     * @return array
     */
    public function getProductConfiguration()
    {
        return ProductConfiguration::get($this->params['params']['packageid']);
    }

}
