<?php

namespace MGModule\EasyDCIM\Repositories\Install;

use MGModule\EasyDCIM\Helpers\FileDir;
use MGModule\EasyDCIM\MgLibs\Database\Models\EmailTemplates;
use MGModule\EasyDCIM\MgLibs\FileReader\FileReader;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;

/**
 * Description of Install
 *
 * @author Mateusz Pawłowski
 */
class Install extends AbstractRepository
{

    /**
     * Get email tempaltes file
     * Add custom template 
     */
    public function activate()
    {
        $templates = $this->getTemplates();

        $this->activateTempates($templates->emails);
    }

    /**
     * Check is email template exists
     * 
     * @param string $templateName
     * @return object insteandof EmailTemplates
     */
    private function checkEmailTemplate($templateName)
    {
        return EmailTemplates::where('name', $templateName)->first();
    }

    /**
     * Get and read JSON file
     * 
     * @return JSON object
     */
    private function getTemplates()
    {
        $path = FileDir::getConfigDir() . DS . 'emailTemplates.json';

        $file = new FileReader($path);
        return $file->read();
    }

    /**
     * Add new email tempalte
     * 
     * @throw database error
     */
    private function activateTempates($templates)
    {

        foreach ($templates as $template)
        {
            if (!$this->checkEmailTemplate($template->name))
            {
                $emailTemplate          = new EmailTemplates();
                $emailTemplate->type    = $template->type;
                $emailTemplate->custom  = $template->custom;
                $emailTemplate->name    = $template->name;
                $emailTemplate->subject = $template->subject;
                $emailTemplate->message = $template->message;
                $emailTemplate->save();
            }
        }
    }

}
