<?php

namespace MGModule\EasyDCIM\Repositories\Invoices;

use Carbon\Carbon;
use Exception;
use MGModule\EasyDCIM\Helpers\AdvancedBilling;
use MGModule\EasyDCIM\Helpers\CustomFields;
use MGModule\EasyDCIM\Helpers\InvoicingDate;
use MGModule\EasyDCIM\Helpers\ProductConfiguration;
use MGModule\EasyDCIM\MgLibs\Database\Models\Hostings;
use MGModule\EasyDCIM\MgLibs\Database\Models\InvoiceItems;
use MGModule\EasyDCIM\MgLibs\Database\Models\Product;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;

/**
 * Description of Graph
 *
 * @author Mateusz Pawłowski
 */
class Invoices extends AbstractRepository
{
    /*
     * Customize Invoice when AB is not activated
     * 
     * @return array
     */

    public function customize()
    {
//check Advaced Billing is active
        try
        {
            if (AdvancedBilling::isActive())
            {
                return;
            }

            $items = $this->getItem();


            if (!$items)
            {
                return;
            }

            $products = Product::where([
                        ['servertype', 'EasyDCIM'],
                        ['overagesenabled', 'LIKE', '%1%'],
                    ])->get();
            $newItems = [];
            foreach ($products as $product)
            {
                $services = Hostings::where([
                            ['domainstatus', 'Active'],
                            ['packageid', $product->id],
                            ['userid', $items->userid]
                        ])->get();


                foreach ($services as $service)
                {
                    if (CustomFields::get($service->packageid, $service->id, 'bandwidthUsageFromRegistrationDate') == "on")
                    {
                        $startDate = InvoicingDate::checkAndGetDate($service->id);
                    }
                    else
                    {
                        $startDate = InvoicingDate::getFirstDay();
                    }
                    $endDate = Carbon::now()->toDateString();
                    $this->changeItemDate($items, $startDate, $endDate);



                    $percentil          = CustomFields::get($service->packageid, $service->id, 'percentileUsage');
                    $percentilCost      = ProductConfiguration::getOne($service->packageid, 'percentileCost');
                    $percentilSoftLimit = ProductConfiguration::getOne($service->packageid, 'percentileSoftLimit');


                    if (empty($percentilCost) || !is_numeric($percentilCost) || $percentilCost <= 0)
                    {
                        return;
                    }
                    if ($percentil)
                    {
                        if ($percentil <= $percentilSoftLimit)
                        {
                            return;
                        }
                        $newItems[] = $this->createNewRecord($service, $percentil, $percentilCost, $percentilSoftLimit, $startDate, $endDate);
                    }
                }
            }
            $this->updateInvoice($newItems);
        }
        catch (Exception $ex)
        {
            //
        }
    }

    private function changeItemDate($item, $startDate, $endDate)
    {
        $oldDesc           = $item->description;
        $arr               = explode(PHP_EOL, $oldDesc);
        $newDate           = sprintf('(%s - %s)', $startDate, $endDate);
        $arr[0]            = preg_replace("/\([0-9\/\.\- ]+\-[0-9\/\.\- ]+\)/", $newDate, $arr[0]);
        $item->description = implode(PHP_EOL, $arr);
        $item->save();
    }

    /*
     * Get invoice item
     * 
     * @return object insteandof InvoiceItems
     */

    private function getItem()
    {
        return InvoiceItems::where([
                    ['invoiceid', $this->params['invoiceid']],
                    ['description', 'LIKE', '%Total Bandwidth Usage%']
                ])->first();
    }

    /*
     * Create new item on invoice 
     * 
     * @param $service insteandof Hostings, float  $percentilCost integer $percentil,$percentilSoftLimit
     * 
     * @return array
     */

    private function createNewRecord(Hostings $service, $percentil, $percentilCost, $percentilSoftLimit, $startDate, $endDate)
    {
        $percentileToBill = ($percentil - $percentilSoftLimit);
        $ammount          = $percentileToBill * $percentilCost;

        $description = sprintf("%s (%s - %s)\n", $service->product->name, $startDate, $endDate);
        $description .= sprintf("Total Percentile Usage = %s Mbps - Overage Charge = %s Mbps @ %s/Mbps", $percentil, $percentileToBill, $percentilCost);
        return [
            'newitemdescription' => $description,
            'newitemamount'      => $ammount,
            'newitemtaxed'       => $service->product->tax
        ];
    }

    /*
     * Update invoice via WHMCS local API
     * 
     * @param array $values integer $productID
     */

    private function updateInvoice($values)
    {
        $postData = [
            "invoiceid"          => $this->params['invoiceid'],
            "itemdescription"    => [],
            "itemamount"         => [],
            "itemtaxed"          => [],
            "newitemdescription" => [],
            "newitemamount"      => [],
            "newitemtaxed"       => [],
            "deletelineids"      => []
        ];
        foreach ($values as $value)
        {
            $postData['newitemdescription'][] = $value['newitemdescription'];
            $postData['newitemamount'][]      = $value['newitemamount'];
            $postData['newitemtaxed'][]       = $value['newitemtaxed'];
        }
        $info = localAPI('updateinvoice', $postData);
    }

}
