<?php

namespace MGModule\EasyDCIM\Repositories\Modules;

use MGModule\EasyDCIM\MgLibs\EasyDCIM\Adapters\ClientAdapter;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\EasyDCIM;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Exceptions\FatalError;
use MGModule\EasyDCIM\MgLibs\EasyDCIM\Models\Devices\Bandwidth;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;
use MGModule\EasyDCIM\Repositories\Graphs\Graph;
use MGModule\EasyDCIM\Repositories\Modules\Traits\TraitModules;

/**
 * Description of DnsManager
 *
 * @author Mateusz Pawłowski
 */
class UsageCollector extends AbstractRepository
{

    use TraitModules;

    /*
     * Check Usage Collector Manager is active
     * Return simple inforamtion
     * 
     * @return array
     * 
     */

    public function check()
    {
        if (!$this->checkIsPageEnable('usageCollector'))
        {
            throw new FatalError('noAccessDNSManager');
        }
        return $this->getInforamtion();
    }

    /**
     * Get date and check available graphs in Graphs Repository
     *
     * @return array
     */
    private function getInforamtion()
    {
        $repository    = new Graph($this->params);

        $rangeDate = $repository->getDateMax();
        $displayDate = $repository->getDisplayDate();

        $vars          = array_merge($rangeDate, $displayDate);
        $vars['graph'] = in_array('AggregateTraffic', $repository->getProductConfiguration()['caSelectedGraphs']);
        return $vars;
    }

    /*
     * Get Traffic Graph
     * 
     * $param integer $width, $height
     * @return array
     */

    public function getGraph()
    {
        $repository = new Graph($this->params);
        if (!in_array('AggregateTraffic', $repository->getProductConfiguration()['caSelectedGraphs']))
        {
            return [];
        }
        return [
            'graphIMG' => $repository->getGraph('AggregateTraffic', 720, 300, $this->params['startDate'], $this->params['endDate']),
        ];
    }

    /*
     * Get Bandwidth
     * 
     * $param integer $width, $height
     * @return array
     */

    public function getBandwidth($tempalteDir = null)
    {
        $repository = new Graph($this->params);
        $dataRange  = $repository->getDataRange();
        $bandwidth  = $this->getBandwidthInformation($dataRange['startDate']->format('Y-m-d'), $dataRange['endDate']->format('Y-m-d'));

        return ['bandwidth' => $this->tableParseRow($tempalteDir . 'bandwidthrow', $bandwidth)];
    }

    /*
     * Get Bandwidth information from Easy DCIM
     * 
     * @param string $startDate, $endDate, $units
     * @return array
     */

    public function getBandwidthInformation($startDate, $endDate, $units = 'GB')
    {
        if ($endDate == \Carbon\Carbon::now()->toDateString())
        {
            $endDate = \Carbon\Carbon::now()->toDateTimeString();
        }
        else
        {
            $endDate .= ' 23:59:59';
        }
        $client         = new ClientAdapter($this->params);
        $bandwidthModel = new Bandwidth();
        $bandwidthModel->setStartDate($startDate . ' 00:00:01')
                ->setEndDate($endDate)
                ->setUnits($units);
        $startDate .= ' 00:00:01';

        $api       = new EasyDCIM($client);
        $bandwidth = $api->device->bandwidth($bandwidthModel);
        return $this->parseBandwidth($bandwidth, $startDate, $endDate);
    }

    /*
     * Parse Bandwidth information
     * 
     * @param json obejct $bandwidth string $startDate, $endDate
     * @return array
     */

    protected function parseBandwidth($bandwidth, $startDate, $endDate)
    {
        return [
            'dateRange'      => $startDate . ' - ' . $endDate,
            'bandwidthIn'    => $bandwidth->BW_IN,
            'bandwidthOut'   => $bandwidth->BW_OUT,
            'bandwidthTotal' => $bandwidth->BW_TOTAL
        ];
    }

}
