<?php

namespace MGModule\EasyDCIM\Repositories\Product;

use MGModule\EasyDCIM\MgLibs\EasyDCIM\Adapters\ClientAdapter;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;
use MGModule\EasyDCIM\Repositories\Product\Fields\AdvancedBilling;
use MGModule\EasyDCIM\Repositories\Product\Fields\DeviceInformation;

/**
 * Description of Install
 *
 * @author Mateusz Pawłowski
 */
class ProductFields extends AbstractRepository
{

    /**
     * Get Custom Template for product information page
     * 
     * @return array
     * 
     */
    public function getCustomPage()
    {
        /*
         * Advanced Billing Field
         */
        $advancedBilling       = new AdvancedBilling($this->params);
        $advancedBillingFields = $advancedBilling->getField();
        /*
         * Graphs Field
         */
        $deviceInformation     = new DeviceInformation($this->params);
        $deviceFields          = $deviceInformation->getField();

        return array_merge($advancedBillingFields, $deviceFields);
    }

    /**
     * Get JS to fix button on client area
     * WHMCS Bug
     * 
     * @return string
     */
    public function getFixWHMCSProductPage()
    {
        return '<script type="text/javascript" src="modules/servers/EasyDCIM/Templates/clientarea/default/assets/js/productRepair.js"></script>';
    }

    /**
     * Get Client Area visible pages
     * 
     * @return array $buttonsArray
     */
    public function getVisiblePages()
    {
        $client       = new ClientAdapter($this->params);
        $buttonsArray = [];
        if ($client->getTrafficAction() == 1)
        {
            $buttonsArray['Traffic Statistics'] = "TrafficStatistics";
        }
        if ($client->getPowerUsageAction() == 1)
        {
            $buttonsArray['Power Usage Statistics'] = "PowerUsageStatistics";
        }
        if ($client->getPowerOutletsAction() == 1)
        {
            $buttonsArray['Power Outlets'] = "PowerOutlets";
        }
        return $buttonsArray;
    }
    

}
