<?php

namespace MGModule\EasyDCIM\Repositories\Sidebar;

use MGModule\EasyDCIM\Helpers\CustomFields;
use MGModule\EasyDCIM\Helpers\ProductConfiguration;
use MGModule\EasyDCIM\MgLibs\Database\Models\Hostings;
use MGModule\EasyDCIM\MgLibs\Lang;
use MGModule\EasyDCIM\MgLibs\Models\AbstractRepository;
use WHMCS\ClientArea;

/**
 * Description of Install
 *
 * @author Mateusz Pawłowski
 */
class Sidebar extends AbstractRepository
{
    /*
     * Load Sidebar settings
     * Check is user logged
     */

    public function loadSidebar()
    {
        $hosting = $this->getAndCheckHosting();

        if ($this->validateCustomField($hosting))
        {
            $this->changeSidebar($hosting);
        }
    }

    public function validateCustomField($hosting = null)
    {
       if(is_null($hosting))
       {

           return false;
       }

       if(empty(CustomFields::get($hosting->packageid, $hosting->id, 'OrderID')))
       {

           return false;
       }

       if(empty(CustomFields::get($hosting->packageid, $hosting->id, 'ServerID')))
       {

           return false;
       }

       return true;
    }

    /*
     * Load and check is Easy DCIM Product
     * 
     * @return object $hosting insteand of Hostings
     */

    private function getAndCheckHosting()
    {
        $hosting = Hostings::where('id', $_REQUEST['id'])->first();
        if (is_null($hosting) || $hosting->product->servertype != "EasyDCIM")
        {
            return null;
        }
        return $hosting;
    }

    /*
     * Add activated modules to sidebar
     * 
     * @param object $hosting insteand of Hostings
     * 
     */

    private function changeSidebar(Hostings $hosting)
    {
        $settings = ProductConfiguration::get($hosting->product->id);

        if (!in_array('changePassword', $settings['caSidebarActions']))
        {
            $this->hideChangePassword();
        }
        if (in_array('dnsManager', $settings['modules']))
        {
            $this->addDNSManager();
        }
        if (in_array('usageCollector', $settings['modules']) || in_array('clientTraffic', $settings['modules']))
        {
            $sidebar = $this->addStatisicBar();

            if(in_array('usageCollector', $settings['modules'])){
                $this->addUsageCollector($sidebar);
            }
            if(in_array('clientTraffic', $settings['modules'])){
                $this->addClientTraffic($sidebar);
            }

        }
        if (in_array('osInstallation', $settings['modules']))
        {
            $this->addOsInstallation();
        }
        if (in_array('passwordManagement', $settings['modules']))
        {
            $this->addPasswordManagement();
        }
    }

    /*
     * Hide password page in client area
     * 
     * Before hide, check "Service Details Actions" is exsist
     * 
     */

    private function hideChangePassword()
    {
        $detailsSidebarObject = $this->params->getChild('Service Details Actions');
        if (is_object($detailsSidebarObject))
        {
            $detailsSidebarObject->removeChild('Change Password');
        }
    }

    /*
     * Add Password Management to sidebar
     */

    private function addPasswordManagement()
    {

        $instance = $this->params->addChild(
            'passwordManagement', [
                'name'  => 'passwordManagement',
                'label' => Lang::absoluteT('PasswordManagement'),
                'icon'  => 'glyphicon-th-list',
                'order' => 20
            ]
        );
        $instance->addChild(
            'reverseDns', [
                'name'  => 'passwordManagement',
                'label' => Lang::absoluteT('accessList'),
                'uri'   => $this->getLink('PasswordManagement')
            ]
        )->setClass(( (isset($_GET['mg-page']) && $_GET['mg-page'] == 'PasswordManagement') ? 'active' : ''));
    }

    /*
     * Add DNS Manager to sidebar
     */

    private function addDNSManager()
    {

        $dnsManager = $this->params->addChild(
                'dnsManager', [
            'name'  => 'dnsManager',
            'label' => Lang::absoluteT('DNSManager'),
            'icon'  => 'glyphicon-globe',
            'order' => 21
                ]
        );
        $dnsManager->addChild(
                'reverseDns', [
            'name'  => 'reverseDNS',
            'label' => Lang::absoluteT('reverseDNS'),
            'uri'   => $this->getLink('DnsManager')
                ]
        )->setClass(( (isset($_GET['mg-page']) && $_GET['mg-page'] == 'DnsManager') ? 'active' : ''));
    }

    /*
     * Add Usage Collector to sidebar
     */

    private function addStatisicBar()
    {
        $usageCollector = $this->params->addChild(
            'trafficStatistics', [
                'name'  => 'usageCollector',
                'label' => Lang::absoluteT('usageCollector'),
                'icon'  => 'glyphicon-stats',
                'order' => 22
            ]
        );

        return $usageCollector;
    }
    private function addUsageCollector($usageCollector)
    {

        $usageCollector->addChild(
                'trafficBilling', [
            'name'  => 'trafficStatistics',
            'label' => Lang::absoluteT('trafficStatistics'),
            'uri'   => $this->getLink('UsageCollector')
                ]
        )->setClass(( (isset($_GET['mg-page']) && $_GET['mg-page'] == 'UsageCollector') ? 'active' : ''));
    }
    private function addClientTraffic($usageCollector)
    {

        $usageCollector->addChild(
                'clientTraffic', [
            'name'  => 'clientTraffic',
            'label' => Lang::absoluteT('clientTraffic'),
            'uri'   => $this->getLink('ClientTraffic')
                ]
        )->setClass(( (isset($_GET['mg-page']) && $_GET['mg-page'] == 'ClientTraffic') ? 'active' : ''));
    }

    /*
     * Add Os Installation to sidebar
     */

    private function addOsInstallation()
    {
        $osInstallation = $this->params->addChild(
                'osInstallation', [
            'name'  => 'osInstallation',
            'label' => Lang::absoluteT('osInstallation'),
            'icon'  => 'glyphicon-list',
            'order' => 23
                ]
        );
        $osInstallation->addChild(
                'rebuild', [
            'name'  => 'rebuild',
            'label' => Lang::absoluteT('rebuild'),
            'uri'   => $this->getLink('OsInstallation')
                ]
        )->setClass(( (isset($_GET['mg-page']) && $_GET['mg-page'] == 'OsInstallation') ? 'active' : ''));
    }

    /*
     * Get link to siedbar button
     */

    private function getLink($module)
    {
        $params = [
            'action'  => 'productdetails',
            'id'      => $_REQUEST['id'],
            'modop'   => 'custom',
            'a'       => 'management',
            'mg-page' => $module
        ];
        return 'clientarea.php?' . http_build_query($params);
    }

}
