<?php

namespace MGModule\EasyDCIM;

use Exception;
use MGModule\EasyDCIM\MgLibs\Error\Register;
use MGModule\EasyDCIM\MgLibs\Hooks\HooksManager;
use MGModule\EasyDCIM\MgLibs\Lang;
use MGModule\EasyDCIM\MgLibs\Process\AbstractMainDriver;
use MGModule\EasyDCIM\MgLibs\Smarty;

/**
 * Description of Addon
 *
 * @author Michal Czech <michael@modulesgarden.com>
 * @SuppressWarnings(PHPMD)
 */
class Server extends AbstractMainDriver
{

    /**
     * Return Tempalates Path
     * 
     * @param boolean $relative
     * @return string
     */
    static function getModuleTemplatesDir($relative = false)
    {

        $dir = ($relative) ? '' : (__DIR__ . DS);

        $dir .= 'Templates' . DS;

        if (self::I()->isAdmin())
        {
            return $dir . 'admin';
        }

        $template = $GLOBALS['CONFIG']['Template'];

        if (file_exists(__DIR__ . DS . 'Templates' . DS . 'clientarea' . DS . $template))
        {
            return $dir . 'clientarea' . DS . $template;
        }
        return $dir . 'clientarea' . DS . 'default';
    }

    public function getAssetsURL()
    {
        if ($this->isAdmin())
        {
            return '../modules/servers/' . $this->configuration()->systemName . '/Templates/admin/assets';
        }
        return 'modules/servers/' . $this->configuration()->systemName . '/' . self::getModuleTemplatesDir(true) . '/assets';
    }

    public function getType()
    {
        return 'Server';
    }

    public static function getMainDIR()
    {
        return __DIR__;
    }

    public static function getUrl()
    {
        return false;
    }

    static function genJSONUrl($page)
    {
        if ($this->isAdmin())
        {
            return false;
        }
        else
        {
            return 'modules/servers/' . $this->configuration()->systemName . '/' . self::getModuleTemplatesDir(true) . '/assets';
        }
    }

    /**
     * Get HTML Client Ara Page
     * 
     * @author Michal Czech <michael@modulesgarden.com>
     * @param array $params
     * @param array $input
     * @return string
     */
    static function getHTMLClientAreaPage($params, $input)
    {
        try
        {
            self::I()->isAdmin(false);
            self::I()->setMainLangContext();
            try
            {
                $page   = empty($input['mg-page']) ? 'Home' : $input['mg-page'];
                $action = empty($input['mg-action']) ? 'index' : $input['mg-action'];

                $input['params'] = $params;

                $output = [
                    'templatefile' => self::I()->getModuleTemplatesDir(true) . '/main'
                ];

                $vars['assetsURL']   = self::I()->getAssetsURL();
                $vars['mainJSONURL'] = 'clientarea.php?action=productdetails&id=' . $params['serviceid'] . '&mg-page=' . $page . '&json=true';

                list($content, $success, $error, $fatalError) = self::I()->runControler($page, $action, $input, 'HTML');

                if (self::I()->isDebug())
                {
                    Smarty::I()->setTemplateDir(self::I()->getModuleTemplatesDir());
                    $vars['isDebugMode'] = Smarty::I()->view('debugmode', ['missingLangs' => Lang::getMissingLangs()]);
                }

                $vars['content']    = $content;
                $vars['success']    = $success;
                $vars['error']      = $error;
                $vars['fatalError'] = ($fatalError) ? Lang::absoluteT('serverCA', $fatalError) : "";
            }
            catch (Exception $ex)
            {
                self::dump($ex);
                Register::register($ex);
                $vars['error'] = Lang::absoluteT('generalError');
                if (method_exists($ex, 'getToken'))
                {
                    $vars['error'] .= ' ' . Lang::absoluteT('token') . $ex->getToken();
                }
            }
            $output['vars'] = $vars;

            return $output;
        }
        catch (Exception $ex)
        {
            self::dump($ex);
            return $ex->getMessage();
        }
    }

    /**
     * Get Json Client Ara Page
     * 
     * @author Michal Czech <michael@modulesgarden.com>
     * @param array $params
     * @param array $input
     * @return string
     */
    static function getJSONClientAreaPage($params, array $input = [])
    {
        try
        {
            self::I()->isAdmin(false);
            self::I()->setMainLangContext();
            $content = [];

            $page   = empty($input['mg-page']) ? 'Home' : $input['mg-page'];
            $action = empty($input['mg-action']) ? 'index' : $input['mg-action'];


            $input['params'] = $params;

            try
            {

                list($result, $success, $error) = self::I()->runControler($page, $action, $input, 'JSON');

                if ($error)
                {
                    $content['error']  = $error;
                    $content['result'] = 'error';
                }
                elseif ($success)
                {
                    $content['success'] = $success;
                    $content['result']  = 'success';
                }

                if (self::I()->isDebug())
                {
                    Smarty::I()->setTemplateDir(self::I()->getModuleTemplatesDir());
                    $vars['isDebugMode'] = Smarty::I()->view('debugmode', ['missingLangs' => Lang::getMissingLangs()]);
                }

                $content['data'] = $result;
            }
            catch (Exception $ex)
            {
                self::dump($ex);
                $content['result'] = 'error';
                Register::register($ex);
                $content['error']  = main\MgLibs\Lang::absoluteT('generalError');
                if (method_exists($ex, 'getToken'))
                {
                    $content['error'] .= ' ' . Lang::absoluteT('token') . $ex->getToken();
                }
            }

            return json_encode($content);
        }
        catch (Exception $ex)
        {
            self::dump($ex);
            return $ex->getMessage();
        }
    }

    /**
     * Run WHMCS Action
     * 
     * @author Michal Czech <michael@modulesgarden.com>
     * @param string $action
     * @param array $input
     * @return string
     */
    static function accountAction($action, $input)
    {
        try
        {
            self::I()->isAdmin(true);
            self::I()->setMainLangContext();

            try
            {
                self::I()->runControler('Actions', $action, [
                    'params' => $input
                        ], 'Action');
                return 'success';
            }
            catch (Exception $ex)
            {
                if (self::I()->isDebug())
                {
                    self::dump($ex);
                    die();
                }

                Register::register($ex);
                $message = $ex->getMessage();
                if (method_exists($ex, 'getToken'))
                {
                    $message .= ' ' . Lang::absoluteT('token') . $ex->getToken();
                }
                return $message;
            }
        }
        catch (Exception $ex)
        {
            self::dump($ex);
            return $ex->getMessage();
        }
    }

    /**
     * Run Custom Controller
     * 
     * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
     * @param string $action
     * @param array $input
     * @return string
     */
    static function getCustomHTMLController($controller, $method, $params)
    {
        try
        {
            self::I()->isAdmin(true);
            self::I()->setMainLangContext();
            try
            {
                $page            = ($controller) ?: 'Home';
                $action          = ($method) ?: 'index';
                $input['params'] = $params;
                return self::I()->runCustomControler($page, $action, $input, 'HTML');
            }
            catch (Exception $ex)
            {
                self::dump($ex);
                Register::register($ex);
                return $ex->getMessage();
            }
        }
        catch (Exception $ex)
        {
            self::dump($ex);
            return $ex->getMessage();
        }
    }

    /**
     * Run Custom Controller
     * 
     * @author Mateusz Pawłowski <mateusz.pa@modulesgarden.com>
     * @param string $action
     * @param array $input
     * @return string
     */
    static function getCustomJSONController($params, $input)
    {
        try
        {
            self::I()->isAdmin(true);
            self::I()->setMainLangContext();
            try
            {
                $page            = ($input['mg-page']) ?: 'Home';
                $action          = ($input['mg-action']) ?: 'index';
                $input['params'] = $params;
                $controller      = self::I()->runCustomControler($page, $action, $input, 'JSON');
                if (isset($controller['success']))
                {
                    $content['success'] = $controller['success'];
                }
                if (isset($controller['error']))
                {
                    $content['error'] = $controller['error'];
                }
                $content['data'] = $controller;
                return json_encode($content);
            }
            catch (Exception $ex)
            {
                self::dump($ex);
                Register::register($ex);
                return $ex->getMessage();
            }
        }
        catch (Exception $ex)
        {
            self::dump($ex);
            return $ex->getMessage();
        }
    }

    /**
     * Get HTML Product Config Page
     * 
     * @author Michal Czech <michael@modulesgarden.com>
     * @param array $input
     * @return string
     */
    static function getHTMLProductConfigPage($input)
    {
        try
        {
            self::I()->isAdmin(true);
            self::I()->setMainLangContext();

            $page   = empty($input['mg-page']) ? 'Configuration' : $input['mg-page'];
            $action = empty($input['mg-action']) ? 'index' : $input['mg-action'];

            $input['params'] = [
                'pid' => $input['id']
            ];

            $vars = [
                'mainURL'     => 'configproducts.php?action=edit&id=' . $input['id'] . '&tab=3',
                'mainName'    => self::I()->configuration()->name,
                'mainJSONURL' => 'configproducts.php?action=edit&id=' . $input['id'] . '&json=1',
                'assetsURL'   => self::I()->getAssetsURL()
            ];

            try
            {
                self::I()->configuration()->activate();
                self::I()->migrations()->run();
                list($content, $success, $error) = self::I()->runControler($page, $action, $input, 'HTML');

                $vars['content'] = $content;
                $vars['success'] = $success;
                $vars['error']   = $error;

                if (self::I()->isDebug())
                {
                    Smarty::I()->setTemplateDir(self::I()->getModuleTemplatesDir());
                    $vars['isDebugMode'] = Smarty::I()->view('debugmode', ['missingLangs' => Lang::getMissingLangs()]);
                }
            }
            catch (Exception $ex)
            {
                Register::register($ex);
                $vars['error'] = $ex->getMessage();
                if (method_exists($ex, 'getToken'))
                {
                    $vars['error'] .= '. ' . Lang::absoluteT('token') . $ex->getToken();
                }
            }

            Smarty::I()->setTemplateDir(self::I()->getModuleTemplatesDir());
            $content = Smarty::I()->view('main', $vars);

            return json_encode(['content' => $content]);
        }
        catch (Exception $ex)
        {
            return $ex->getMessage();
        }
    }

    /**
     * Get JSON Product Config Page
     * 
     * @author Michal Czech <michael@modulesgarden.com>
     * @param array $input
     * @return string
     */
    static function getJSONProductConfigPage($input)
    {
        try
        {
            self::I()->isAdmin(true);
            self::I()->setMainLangContext();

            $content = [];

            $page   = empty($input['mg-page']) ? 'Configuration' : $input['mg-page'];
            $action = empty($input['mg-action']) ? 'index' : $input['mg-action'];

            $input['params'] = [
                'pid' => $input['id']
            ];

            try
            {
                list($result, $success, $error) = self::I()->runControler($page, $action, $input, 'JSON');

                if ($error)
                {
                    $content['error']  = $error;
                    $content['result'] = 'error';
                }
                elseif ($success)
                {
                    $content['success'] = $success;
                    $content['result']  = 'success';
                }

                if (self::I()->isDebug())
                {
                    Smarty::I()->setTemplateDir(self::I()->getModuleTemplatesDir());
                    $vars['isDebugMode'] = Smarty::I()->view('debugmode', ['missingLangs' => Lang::getMissingLangs()]);
                }

                $content['data'] = $result;
            }
            catch (Exception $ex)
            {
                self::dump($ex);
                Register::register($ex);
                $content['result'] = 'error';
                $content['error']  = $ex->getMessage();
                if (method_exists($ex, 'getToken'))
                {
                    $content['error'] .= ' ' . Lang::absoluteT('token') . $ex->getToken();
                }
            }

            return json_encode($content);
        }
        catch (Exception $ex)
        {
            self::dump($ex);
            return $ex->getMessage();
        }
    }

    /**
     * Get Config Product Array
     * Useless if you inject own product configuration
     * 
     * @author Michal Czech <michael@modulesgarden.com>
     * @return array
     */
    static function configArray()
    {
        if (method_exists(self::I()->configuration(), 'getServerWHMCSConfig'))
        {
            $config = self::I()->configuration()->getServerWHMCSConfig();

            if (is_array($config))
            {
                return array_fill_keys($config, [
                    "Type" => "text"
                ]);
            }
        }
        return [];
    }

    /**
     * CRON action
     * 
     * @author Michal Czech <michael@modulesgarden.com>
     */
    static function cron()
    {
        try
        {
            self::I()->isAdmin(true);
            self::I()->setMainLangContext();

            self::I()->runControler('Cron', 'index', $input, 'CRON');
        }
        catch (Exception $ex)
        {
            self::dump($ex);
            Register::register($ex);
        }
    }

    /*
     * Hooks actions
     * 
     * 
     */

    static function hooks()
    {
        try
        {
            self::I()->migrations()->run();
            HooksManager::addHooks(__DIR__);
        }
        catch (Exception $ex)
        {
            self::dump($ex);
            Register::register($ex);
        }
    }

}
